# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/protobuf/descriptor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR = _descriptor.FileDescriptor(
        name="google/protobuf/descriptor.proto",
        package="google.protobuf",
        syntax="proto2",
        serialized_options=None,
        create_key=_descriptor._internal_create_key,
        serialized_pb=b'\n google/protobuf/descriptor.proto\x12\x0fgoogle.protobuf"M\n\x11\x46ileDescriptorSet\x12\x38\n\x04\x66ile\x18\x01 \x03(\x0b\x32$.google.protobuf.FileDescriptorProtoR\x04\x66ile"\xfe\x04\n\x13\x46ileDescriptorProto\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x18\n\x07package\x18\x02 \x01(\tR\x07package\x12\x1e\n\ndependency\x18\x03 \x03(\tR\ndependency\x12+\n\x11public_dependency\x18\n \x03(\x05R\x10publicDependency\x12\'\n\x0fweak_dependency\x18\x0b \x03(\x05R\x0eweakDependency\x12\x43\n\x0cmessage_type\x18\x04 \x03(\x0b\x32 .google.protobuf.DescriptorProtoR\x0bmessageType\x12\x41\n\tenum_type\x18\x05 \x03(\x0b\x32$.google.protobuf.EnumDescriptorProtoR\x08\x65numType\x12\x41\n\x07service\x18\x06 \x03(\x0b\x32\'.google.protobuf.ServiceDescriptorProtoR\x07service\x12\x43\n\textension\x18\x07 \x03(\x0b\x32%.google.protobuf.FieldDescriptorProtoR\textension\x12\x36\n\x07options\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.FileOptionsR\x07options\x12I\n\x10source_code_info\x18\t \x01(\x0b\x32\x1f.google.protobuf.SourceCodeInfoR\x0esourceCodeInfo\x12\x16\n\x06syntax\x18\x0c \x01(\tR\x06syntax\x12\x18\n\x07\x65\x64ition\x18\r \x01(\tR\x07\x65\x64ition"\xb9\x06\n\x0f\x44\x65scriptorProto\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12;\n\x05\x66ield\x18\x02 \x03(\x0b\x32%.google.protobuf.FieldDescriptorProtoR\x05\x66ield\x12\x43\n\textension\x18\x06 \x03(\x0b\x32%.google.protobuf.FieldDescriptorProtoR\textension\x12\x41\n\x0bnested_type\x18\x03 \x03(\x0b\x32 .google.protobuf.DescriptorProtoR\nnestedType\x12\x41\n\tenum_type\x18\x04 \x03(\x0b\x32$.google.protobuf.EnumDescriptorProtoR\x08\x65numType\x12X\n\x0f\x65xtension_range\x18\x05 \x03(\x0b\x32/.google.protobuf.DescriptorProto.ExtensionRangeR\x0e\x65xtensionRange\x12\x44\n\noneof_decl\x18\x08 \x03(\x0b\x32%.google.protobuf.OneofDescriptorProtoR\toneofDecl\x12\x39\n\x07options\x18\x07 \x01(\x0b\x32\x1f.google.protobuf.MessageOptionsR\x07options\x12U\n\x0ereserved_range\x18\t \x03(\x0b\x32..google.protobuf.DescriptorProto.ReservedRangeR\rreservedRange\x12#\n\rreserved_name\x18\n \x03(\tR\x0creservedName\x1az\n\x0e\x45xtensionRange\x12\x14\n\x05start\x18\x01 \x01(\x05R\x05start\x12\x10\n\x03\x65nd\x18\x02 \x01(\x05R\x03\x65nd\x12@\n\x07options\x18\x03 \x01(\x0b\x32&.google.protobuf.ExtensionRangeOptionsR\x07options\x1a\x37\n\rReservedRange\x12\x14\n\x05start\x18\x01 \x01(\x05R\x05start\x12\x10\n\x03\x65nd\x18\x02 \x01(\x05R\x03\x65nd"|\n\x15\x45xtensionRangeOptions\x12X\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32$.google.protobuf.UninterpretedOptionR\x13uninterpretedOption*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02"\xc1\x06\n\x14\x46ieldDescriptorProto\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x16\n\x06number\x18\x03 \x01(\x05R\x06number\x12\x41\n\x05label\x18\x04 \x01(\x0e\x32+.google.protobuf.FieldDescriptorProto.LabelR\x05label\x12>\n\x04type\x18\x05 \x01(\x0e\x32*.google.protobuf.FieldDescriptorProto.TypeR\x04type\x12\x1b\n\ttype_name\x18\x06 \x01(\tR\x08typeName\x12\x1a\n\x08\x65xtendee\x18\x02 \x01(\tR\x08\x65xtendee\x12#\n\rdefault_value\x18\x07 \x01(\tR\x0c\x64\x65\x66\x61ultValue\x12\x1f\n\x0boneof_index\x18\t \x01(\x05R\noneofIndex\x12\x1b\n\tjson_name\x18\n \x01(\tR\x08jsonName\x12\x37\n\x07options\x18\x08 \x01(\x0b\x32\x1d.google.protobuf.FieldOptionsR\x07options\x12\'\n\x0fproto3_optional\x18\x11 \x01(\x08R\x0eproto3Optional"\xb6\x02\n\x04Type\x12\x0f\n\x0bTYPE_DOUBLE\x10\x01\x12\x0e\n\nTYPE_FLOAT\x10\x02\x12\x0e\n\nTYPE_INT64\x10\x03\x12\x0f\n\x0bTYPE_UINT64\x10\x04\x12\x0e\n\nTYPE_INT32\x10\x05\x12\x10\n\x0cTYPE_FIXED64\x10\x06\x12\x10\n\x0cTYPE_FIXED32\x10\x07\x12\r\n\tTYPE_BOOL\x10\x08\x12\x0f\n\x0bTYPE_STRING\x10\t\x12\x0e\n\nTYPE_GROUP\x10\n\x12\x10\n\x0cTYPE_MESSAGE\x10\x0b\x12\x0e\n\nTYPE_BYTES\x10\x0c\x12\x0f\n\x0bTYPE_UINT32\x10\r\x12\r\n\tTYPE_ENUM\x10\x0e\x12\x11\n\rTYPE_SFIXED32\x10\x0f\x12\x11\n\rTYPE_SFIXED64\x10\x10\x12\x0f\n\x0bTYPE_SINT32\x10\x11\x12\x0f\n\x0bTYPE_SINT64\x10\x12"C\n\x05Label\x12\x12\n\x0eLABEL_OPTIONAL\x10\x01\x12\x12\n\x0eLABEL_REQUIRED\x10\x02\x12\x12\n\x0eLABEL_REPEATED\x10\x03"c\n\x14OneofDescriptorProto\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x37\n\x07options\x18\x02 \x01(\x0b\x32\x1d.google.protobuf.OneofOptionsR\x07options"\xe3\x02\n\x13\x45numDescriptorProto\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12?\n\x05value\x18\x02 \x03(\x0b\x32).google.protobuf.EnumValueDescriptorProtoR\x05value\x12\x36\n\x07options\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.EnumOptionsR\x07options\x12]\n\x0ereserved_range\x18\x04 \x03(\x0b\x32\x36.google.protobuf.EnumDescriptorProto.EnumReservedRangeR\rreservedRange\x12#\n\rreserved_name\x18\x05 \x03(\tR\x0creservedName\x1a;\n\x11\x45numReservedRange\x12\x14\n\x05start\x18\x01 \x01(\x05R\x05start\x12\x10\n\x03\x65nd\x18\x02 \x01(\x05R\x03\x65nd"\x83\x01\n\x18\x45numValueDescriptorProto\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x16\n\x06number\x18\x02 \x01(\x05R\x06number\x12;\n\x07options\x18\x03 \x01(\x0b\x32!.google.protobuf.EnumValueOptionsR\x07options"\xa7\x01\n\x16ServiceDescriptorProto\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12>\n\x06method\x18\x02 \x03(\x0b\x32&.google.protobuf.MethodDescriptorProtoR\x06method\x12\x39\n\x07options\x18\x03 \x01(\x0b\x32\x1f.google.protobuf.ServiceOptionsR\x07options"\x89\x02\n\x15MethodDescriptorProto\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1d\n\ninput_type\x18\x02 \x01(\tR\tinputType\x12\x1f\n\x0boutput_type\x18\x03 \x01(\tR\noutputType\x12\x38\n\x07options\x18\x04 \x01(\x0b\x32\x1e.google.protobuf.MethodOptionsR\x07options\x12\x30\n\x10\x63lient_streaming\x18\x05 \x01(\x08:\x05\x66\x61lseR\x0f\x63lientStreaming\x12\x30\n\x10server_streaming\x18\x06 \x01(\x08:\x05\x66\x61lseR\x0fserverStreaming"\x91\t\n\x0b\x46ileOptions\x12!\n\x0cjava_package\x18\x01 \x01(\tR\x0bjavaPackage\x12\x30\n\x14java_outer_classname\x18\x08 \x01(\tR\x12javaOuterClassname\x12\x35\n\x13java_multiple_files\x18\n \x01(\x08:\x05\x66\x61lseR\x11javaMultipleFiles\x12\x44\n\x1djava_generate_equals_and_hash\x18\x14 \x01(\x08\x42\x02\x18\x01R\x19javaGenerateEqualsAndHash\x12:\n\x16java_string_check_utf8\x18\x1b \x01(\x08:\x05\x66\x61lseR\x13javaStringCheckUtf8\x12S\n\x0coptimize_for\x18\t \x01(\x0e\x32).google.protobuf.FileOptions.OptimizeMode:\x05SPEEDR\x0boptimizeFor\x12\x1d\n\ngo_package\x18\x0b \x01(\tR\tgoPackage\x12\x35\n\x13\x63\x63_generic_services\x18\x10 \x01(\x08:\x05\x66\x61lseR\x11\x63\x63GenericServices\x12\x39\n\x15java_generic_services\x18\x11 \x01(\x08:\x05\x66\x61lseR\x13javaGenericServices\x12\x35\n\x13py_generic_services\x18\x12 \x01(\x08:\x05\x66\x61lseR\x11pyGenericServices\x12\x37\n\x14php_generic_services\x18* \x01(\x08:\x05\x66\x61lseR\x12phpGenericServices\x12%\n\ndeprecated\x18\x17 \x01(\x08:\x05\x66\x61lseR\ndeprecated\x12.\n\x10\x63\x63_enable_arenas\x18\x1f \x01(\x08:\x04trueR\x0e\x63\x63\x45nableArenas\x12*\n\x11objc_class_prefix\x18$ \x01(\tR\x0fobjcClassPrefix\x12)\n\x10\x63sharp_namespace\x18% \x01(\tR\x0f\x63sharpNamespace\x12!\n\x0cswift_prefix\x18\' \x01(\tR\x0bswiftPrefix\x12(\n\x10php_class_prefix\x18( \x01(\tR\x0ephpClassPrefix\x12#\n\rphp_namespace\x18) \x01(\tR\x0cphpNamespace\x12\x34\n\x16php_metadata_namespace\x18, \x01(\tR\x14phpMetadataNamespace\x12!\n\x0cruby_package\x18- \x01(\tR\x0brubyPackage\x12X\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32$.google.protobuf.UninterpretedOptionR\x13uninterpretedOption":\n\x0cOptimizeMode\x12\t\n\x05SPEED\x10\x01\x12\r\n\tCODE_SIZE\x10\x02\x12\x10\n\x0cLITE_RUNTIME\x10\x03*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02J\x04\x08&\x10\'"\xbb\x03\n\x0eMessageOptions\x12<\n\x17message_set_wire_format\x18\x01 \x01(\x08:\x05\x66\x61lseR\x14messageSetWireFormat\x12L\n\x1fno_standard_descriptor_accessor\x18\x02 \x01(\x08:\x05\x66\x61lseR\x1cnoStandardDescriptorAccessor\x12%\n\ndeprecated\x18\x03 \x01(\x08:\x05\x66\x61lseR\ndeprecated\x12\x1b\n\tmap_entry\x18\x07 \x01(\x08R\x08mapEntry\x12V\n&deprecated_legacy_json_field_conflicts\x18\x0b \x01(\x08\x42\x02\x18\x01R"deprecatedLegacyJsonFieldConflicts\x12X\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32$.google.protobuf.UninterpretedOptionR\x13uninterpretedOption*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07J\x04\x08\x08\x10\tJ\x04\x08\t\x10\n"\xb7\x08\n\x0c\x46ieldOptions\x12\x41\n\x05\x63type\x18\x01 \x01(\x0e\x32#.google.protobuf.FieldOptions.CType:\x06STRINGR\x05\x63type\x12\x16\n\x06packed\x18\x02 \x01(\x08R\x06packed\x12G\n\x06jstype\x18\x06 \x01(\x0e\x32$.google.protobuf.FieldOptions.JSType:\tJS_NORMALR\x06jstype\x12\x19\n\x04lazy\x18\x05 \x01(\x08:\x05\x66\x61lseR\x04lazy\x12.\n\x0funverified_lazy\x18\x0f \x01(\x08:\x05\x66\x61lseR\x0eunverifiedLazy\x12%\n\ndeprecated\x18\x03 \x01(\x08:\x05\x66\x61lseR\ndeprecated\x12\x19\n\x04weak\x18\n \x01(\x08:\x05\x66\x61lseR\x04weak\x12(\n\x0c\x64\x65\x62ug_redact\x18\x10 \x01(\x08:\x05\x66\x61lseR\x0b\x64\x65\x62ugRedact\x12K\n\tretention\x18\x11 \x01(\x0e\x32-.google.protobuf.FieldOptions.OptionRetentionR\tretention\x12\x46\n\x06target\x18\x12 \x01(\x0e\x32..google.protobuf.FieldOptions.OptionTargetTypeR\x06target\x12X\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32$.google.protobuf.UninterpretedOptionR\x13uninterpretedOption"/\n\x05\x43Type\x12\n\n\x06STRING\x10\x00\x12\x08\n\x04\x43ORD\x10\x01\x12\x10\n\x0cSTRING_PIECE\x10\x02"5\n\x06JSType\x12\r\n\tJS_NORMAL\x10\x00\x12\r\n\tJS_STRING\x10\x01\x12\r\n\tJS_NUMBER\x10\x02"U\n\x0fOptionRetention\x12\x15\n\x11RETENTION_UNKNOWN\x10\x00\x12\x15\n\x11RETENTION_RUNTIME\x10\x01\x12\x14\n\x10RETENTION_SOURCE\x10\x02"\x8c\x02\n\x10OptionTargetType\x12\x17\n\x13TARGET_TYPE_UNKNOWN\x10\x00\x12\x14\n\x10TARGET_TYPE_FILE\x10\x01\x12\x1f\n\x1bTARGET_TYPE_EXTENSION_RANGE\x10\x02\x12\x17\n\x13TARGET_TYPE_MESSAGE\x10\x03\x12\x15\n\x11TARGET_TYPE_FIELD\x10\x04\x12\x15\n\x11TARGET_TYPE_ONEOF\x10\x05\x12\x14\n\x10TARGET_TYPE_ENUM\x10\x06\x12\x1a\n\x16TARGET_TYPE_ENUM_ENTRY\x10\x07\x12\x17\n\x13TARGET_TYPE_SERVICE\x10\x08\x12\x16\n\x12TARGET_TYPE_METHOD\x10\t*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02J\x04\x08\x04\x10\x05"s\n\x0cOneofOptions\x12X\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32$.google.protobuf.UninterpretedOptionR\x13uninterpretedOption*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02"\x98\x02\n\x0b\x45numOptions\x12\x1f\n\x0b\x61llow_alias\x18\x02 \x01(\x08R\nallowAlias\x12%\n\ndeprecated\x18\x03 \x01(\x08:\x05\x66\x61lseR\ndeprecated\x12V\n&deprecated_legacy_json_field_conflicts\x18\x06 \x01(\x08\x42\x02\x18\x01R"deprecatedLegacyJsonFieldConflicts\x12X\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32$.google.protobuf.UninterpretedOptionR\x13uninterpretedOption*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02J\x04\x08\x05\x10\x06"\x9e\x01\n\x10\x45numValueOptions\x12%\n\ndeprecated\x18\x01 \x01(\x08:\x05\x66\x61lseR\ndeprecated\x12X\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32$.google.protobuf.UninterpretedOptionR\x13uninterpretedOption*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02"\x9c\x01\n\x0eServiceOptions\x12%\n\ndeprecated\x18! \x01(\x08:\x05\x66\x61lseR\ndeprecated\x12X\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32$.google.protobuf.UninterpretedOptionR\x13uninterpretedOption*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02"\xe0\x02\n\rMethodOptions\x12%\n\ndeprecated\x18! \x01(\x08:\x05\x66\x61lseR\ndeprecated\x12q\n\x11idempotency_level\x18" \x01(\x0e\x32/.google.protobuf.MethodOptions.IdempotencyLevel:\x13IDEMPOTENCY_UNKNOWNR\x10idempotencyLevel\x12X\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32$.google.protobuf.UninterpretedOptionR\x13uninterpretedOption"P\n\x10IdempotencyLevel\x12\x17\n\x13IDEMPOTENCY_UNKNOWN\x10\x00\x12\x13\n\x0fNO_SIDE_EFFECTS\x10\x01\x12\x0e\n\nIDEMPOTENT\x10\x02*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02"\x9a\x03\n\x13UninterpretedOption\x12\x41\n\x04name\x18\x02 \x03(\x0b\x32-.google.protobuf.UninterpretedOption.NamePartR\x04name\x12)\n\x10identifier_value\x18\x03 \x01(\tR\x0fidentifierValue\x12,\n\x12positive_int_value\x18\x04 \x01(\x04R\x10positiveIntValue\x12,\n\x12negative_int_value\x18\x05 \x01(\x03R\x10negativeIntValue\x12!\n\x0c\x64ouble_value\x18\x06 \x01(\x01R\x0b\x64oubleValue\x12!\n\x0cstring_value\x18\x07 \x01(\x0cR\x0bstringValue\x12\'\n\x0f\x61ggregate_value\x18\x08 \x01(\tR\x0e\x61ggregateValue\x1aJ\n\x08NamePart\x12\x1b\n\tname_part\x18\x01 \x02(\tR\x08namePart\x12!\n\x0cis_extension\x18\x02 \x02(\x08R\x0bisExtension"\xa7\x02\n\x0eSourceCodeInfo\x12\x44\n\x08location\x18\x01 \x03(\x0b\x32(.google.protobuf.SourceCodeInfo.LocationR\x08location\x1a\xce\x01\n\x08Location\x12\x16\n\x04path\x18\x01 \x03(\x05\x42\x02\x10\x01R\x04path\x12\x16\n\x04span\x18\x02 \x03(\x05\x42\x02\x10\x01R\x04span\x12)\n\x10leading_comments\x18\x03 \x01(\tR\x0fleadingComments\x12+\n\x11trailing_comments\x18\x04 \x01(\tR\x10trailingComments\x12:\n\x19leading_detached_comments\x18\x06 \x03(\tR\x17leadingDetachedComments"\xd0\x02\n\x11GeneratedCodeInfo\x12M\n\nannotation\x18\x01 \x03(\x0b\x32-.google.protobuf.GeneratedCodeInfo.AnnotationR\nannotation\x1a\xeb\x01\n\nAnnotation\x12\x16\n\x04path\x18\x01 \x03(\x05\x42\x02\x10\x01R\x04path\x12\x1f\n\x0bsource_file\x18\x02 \x01(\tR\nsourceFile\x12\x14\n\x05\x62\x65gin\x18\x03 \x01(\x05R\x05\x62\x65gin\x12\x10\n\x03\x65nd\x18\x04 \x01(\x05R\x03\x65nd\x12R\n\x08semantic\x18\x05 \x01(\x0e\x32\x36.google.protobuf.GeneratedCodeInfo.Annotation.SemanticR\x08semantic"(\n\x08Semantic\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03SET\x10\x01\x12\t\n\x05\x41LIAS\x10\x02\x42~\n\x13\x63om.google.protobufB\x10\x44\x65scriptorProtosH\x01Z-google.golang.org/protobuf/types/descriptorpb\xf8\x01\x01\xa2\x02\x03GPB\xaa\x02\x1aGoogle.Protobuf.Reflection',
    )
else:
    DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
        b'\n google/protobuf/descriptor.proto\x12\x0fgoogle.protobuf"M\n\x11\x46ileDescriptorSet\x12\x38\n\x04\x66ile\x18\x01 \x03(\x0b\x32$.google.protobuf.FileDescriptorProtoR\x04\x66ile"\xfe\x04\n\x13\x46ileDescriptorProto\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x18\n\x07package\x18\x02 \x01(\tR\x07package\x12\x1e\n\ndependency\x18\x03 \x03(\tR\ndependency\x12+\n\x11public_dependency\x18\n \x03(\x05R\x10publicDependency\x12\'\n\x0fweak_dependency\x18\x0b \x03(\x05R\x0eweakDependency\x12\x43\n\x0cmessage_type\x18\x04 \x03(\x0b\x32 .google.protobuf.DescriptorProtoR\x0bmessageType\x12\x41\n\tenum_type\x18\x05 \x03(\x0b\x32$.google.protobuf.EnumDescriptorProtoR\x08\x65numType\x12\x41\n\x07service\x18\x06 \x03(\x0b\x32\'.google.protobuf.ServiceDescriptorProtoR\x07service\x12\x43\n\textension\x18\x07 \x03(\x0b\x32%.google.protobuf.FieldDescriptorProtoR\textension\x12\x36\n\x07options\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.FileOptionsR\x07options\x12I\n\x10source_code_info\x18\t \x01(\x0b\x32\x1f.google.protobuf.SourceCodeInfoR\x0esourceCodeInfo\x12\x16\n\x06syntax\x18\x0c \x01(\tR\x06syntax\x12\x18\n\x07\x65\x64ition\x18\r \x01(\tR\x07\x65\x64ition"\xb9\x06\n\x0f\x44\x65scriptorProto\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12;\n\x05\x66ield\x18\x02 \x03(\x0b\x32%.google.protobuf.FieldDescriptorProtoR\x05\x66ield\x12\x43\n\textension\x18\x06 \x03(\x0b\x32%.google.protobuf.FieldDescriptorProtoR\textension\x12\x41\n\x0bnested_type\x18\x03 \x03(\x0b\x32 .google.protobuf.DescriptorProtoR\nnestedType\x12\x41\n\tenum_type\x18\x04 \x03(\x0b\x32$.google.protobuf.EnumDescriptorProtoR\x08\x65numType\x12X\n\x0f\x65xtension_range\x18\x05 \x03(\x0b\x32/.google.protobuf.DescriptorProto.ExtensionRangeR\x0e\x65xtensionRange\x12\x44\n\noneof_decl\x18\x08 \x03(\x0b\x32%.google.protobuf.OneofDescriptorProtoR\toneofDecl\x12\x39\n\x07options\x18\x07 \x01(\x0b\x32\x1f.google.protobuf.MessageOptionsR\x07options\x12U\n\x0ereserved_range\x18\t \x03(\x0b\x32..google.protobuf.DescriptorProto.ReservedRangeR\rreservedRange\x12#\n\rreserved_name\x18\n \x03(\tR\x0creservedName\x1az\n\x0e\x45xtensionRange\x12\x14\n\x05start\x18\x01 \x01(\x05R\x05start\x12\x10\n\x03\x65nd\x18\x02 \x01(\x05R\x03\x65nd\x12@\n\x07options\x18\x03 \x01(\x0b\x32&.google.protobuf.ExtensionRangeOptionsR\x07options\x1a\x37\n\rReservedRange\x12\x14\n\x05start\x18\x01 \x01(\x05R\x05start\x12\x10\n\x03\x65nd\x18\x02 \x01(\x05R\x03\x65nd"|\n\x15\x45xtensionRangeOptions\x12X\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32$.google.protobuf.UninterpretedOptionR\x13uninterpretedOption*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02"\xc1\x06\n\x14\x46ieldDescriptorProto\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x16\n\x06number\x18\x03 \x01(\x05R\x06number\x12\x41\n\x05label\x18\x04 \x01(\x0e\x32+.google.protobuf.FieldDescriptorProto.LabelR\x05label\x12>\n\x04type\x18\x05 \x01(\x0e\x32*.google.protobuf.FieldDescriptorProto.TypeR\x04type\x12\x1b\n\ttype_name\x18\x06 \x01(\tR\x08typeName\x12\x1a\n\x08\x65xtendee\x18\x02 \x01(\tR\x08\x65xtendee\x12#\n\rdefault_value\x18\x07 \x01(\tR\x0c\x64\x65\x66\x61ultValue\x12\x1f\n\x0boneof_index\x18\t \x01(\x05R\noneofIndex\x12\x1b\n\tjson_name\x18\n \x01(\tR\x08jsonName\x12\x37\n\x07options\x18\x08 \x01(\x0b\x32\x1d.google.protobuf.FieldOptionsR\x07options\x12\'\n\x0fproto3_optional\x18\x11 \x01(\x08R\x0eproto3Optional"\xb6\x02\n\x04Type\x12\x0f\n\x0bTYPE_DOUBLE\x10\x01\x12\x0e\n\nTYPE_FLOAT\x10\x02\x12\x0e\n\nTYPE_INT64\x10\x03\x12\x0f\n\x0bTYPE_UINT64\x10\x04\x12\x0e\n\nTYPE_INT32\x10\x05\x12\x10\n\x0cTYPE_FIXED64\x10\x06\x12\x10\n\x0cTYPE_FIXED32\x10\x07\x12\r\n\tTYPE_BOOL\x10\x08\x12\x0f\n\x0bTYPE_STRING\x10\t\x12\x0e\n\nTYPE_GROUP\x10\n\x12\x10\n\x0cTYPE_MESSAGE\x10\x0b\x12\x0e\n\nTYPE_BYTES\x10\x0c\x12\x0f\n\x0bTYPE_UINT32\x10\r\x12\r\n\tTYPE_ENUM\x10\x0e\x12\x11\n\rTYPE_SFIXED32\x10\x0f\x12\x11\n\rTYPE_SFIXED64\x10\x10\x12\x0f\n\x0bTYPE_SINT32\x10\x11\x12\x0f\n\x0bTYPE_SINT64\x10\x12"C\n\x05Label\x12\x12\n\x0eLABEL_OPTIONAL\x10\x01\x12\x12\n\x0eLABEL_REQUIRED\x10\x02\x12\x12\n\x0eLABEL_REPEATED\x10\x03"c\n\x14OneofDescriptorProto\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x37\n\x07options\x18\x02 \x01(\x0b\x32\x1d.google.protobuf.OneofOptionsR\x07options"\xe3\x02\n\x13\x45numDescriptorProto\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12?\n\x05value\x18\x02 \x03(\x0b\x32).google.protobuf.EnumValueDescriptorProtoR\x05value\x12\x36\n\x07options\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.EnumOptionsR\x07options\x12]\n\x0ereserved_range\x18\x04 \x03(\x0b\x32\x36.google.protobuf.EnumDescriptorProto.EnumReservedRangeR\rreservedRange\x12#\n\rreserved_name\x18\x05 \x03(\tR\x0creservedName\x1a;\n\x11\x45numReservedRange\x12\x14\n\x05start\x18\x01 \x01(\x05R\x05start\x12\x10\n\x03\x65nd\x18\x02 \x01(\x05R\x03\x65nd"\x83\x01\n\x18\x45numValueDescriptorProto\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x16\n\x06number\x18\x02 \x01(\x05R\x06number\x12;\n\x07options\x18\x03 \x01(\x0b\x32!.google.protobuf.EnumValueOptionsR\x07options"\xa7\x01\n\x16ServiceDescriptorProto\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12>\n\x06method\x18\x02 \x03(\x0b\x32&.google.protobuf.MethodDescriptorProtoR\x06method\x12\x39\n\x07options\x18\x03 \x01(\x0b\x32\x1f.google.protobuf.ServiceOptionsR\x07options"\x89\x02\n\x15MethodDescriptorProto\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1d\n\ninput_type\x18\x02 \x01(\tR\tinputType\x12\x1f\n\x0boutput_type\x18\x03 \x01(\tR\noutputType\x12\x38\n\x07options\x18\x04 \x01(\x0b\x32\x1e.google.protobuf.MethodOptionsR\x07options\x12\x30\n\x10\x63lient_streaming\x18\x05 \x01(\x08:\x05\x66\x61lseR\x0f\x63lientStreaming\x12\x30\n\x10server_streaming\x18\x06 \x01(\x08:\x05\x66\x61lseR\x0fserverStreaming"\x91\t\n\x0b\x46ileOptions\x12!\n\x0cjava_package\x18\x01 \x01(\tR\x0bjavaPackage\x12\x30\n\x14java_outer_classname\x18\x08 \x01(\tR\x12javaOuterClassname\x12\x35\n\x13java_multiple_files\x18\n \x01(\x08:\x05\x66\x61lseR\x11javaMultipleFiles\x12\x44\n\x1djava_generate_equals_and_hash\x18\x14 \x01(\x08\x42\x02\x18\x01R\x19javaGenerateEqualsAndHash\x12:\n\x16java_string_check_utf8\x18\x1b \x01(\x08:\x05\x66\x61lseR\x13javaStringCheckUtf8\x12S\n\x0coptimize_for\x18\t \x01(\x0e\x32).google.protobuf.FileOptions.OptimizeMode:\x05SPEEDR\x0boptimizeFor\x12\x1d\n\ngo_package\x18\x0b \x01(\tR\tgoPackage\x12\x35\n\x13\x63\x63_generic_services\x18\x10 \x01(\x08:\x05\x66\x61lseR\x11\x63\x63GenericServices\x12\x39\n\x15java_generic_services\x18\x11 \x01(\x08:\x05\x66\x61lseR\x13javaGenericServices\x12\x35\n\x13py_generic_services\x18\x12 \x01(\x08:\x05\x66\x61lseR\x11pyGenericServices\x12\x37\n\x14php_generic_services\x18* \x01(\x08:\x05\x66\x61lseR\x12phpGenericServices\x12%\n\ndeprecated\x18\x17 \x01(\x08:\x05\x66\x61lseR\ndeprecated\x12.\n\x10\x63\x63_enable_arenas\x18\x1f \x01(\x08:\x04trueR\x0e\x63\x63\x45nableArenas\x12*\n\x11objc_class_prefix\x18$ \x01(\tR\x0fobjcClassPrefix\x12)\n\x10\x63sharp_namespace\x18% \x01(\tR\x0f\x63sharpNamespace\x12!\n\x0cswift_prefix\x18\' \x01(\tR\x0bswiftPrefix\x12(\n\x10php_class_prefix\x18( \x01(\tR\x0ephpClassPrefix\x12#\n\rphp_namespace\x18) \x01(\tR\x0cphpNamespace\x12\x34\n\x16php_metadata_namespace\x18, \x01(\tR\x14phpMetadataNamespace\x12!\n\x0cruby_package\x18- \x01(\tR\x0brubyPackage\x12X\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32$.google.protobuf.UninterpretedOptionR\x13uninterpretedOption":\n\x0cOptimizeMode\x12\t\n\x05SPEED\x10\x01\x12\r\n\tCODE_SIZE\x10\x02\x12\x10\n\x0cLITE_RUNTIME\x10\x03*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02J\x04\x08&\x10\'"\xbb\x03\n\x0eMessageOptions\x12<\n\x17message_set_wire_format\x18\x01 \x01(\x08:\x05\x66\x61lseR\x14messageSetWireFormat\x12L\n\x1fno_standard_descriptor_accessor\x18\x02 \x01(\x08:\x05\x66\x61lseR\x1cnoStandardDescriptorAccessor\x12%\n\ndeprecated\x18\x03 \x01(\x08:\x05\x66\x61lseR\ndeprecated\x12\x1b\n\tmap_entry\x18\x07 \x01(\x08R\x08mapEntry\x12V\n&deprecated_legacy_json_field_conflicts\x18\x0b \x01(\x08\x42\x02\x18\x01R"deprecatedLegacyJsonFieldConflicts\x12X\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32$.google.protobuf.UninterpretedOptionR\x13uninterpretedOption*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07J\x04\x08\x08\x10\tJ\x04\x08\t\x10\n"\xb7\x08\n\x0c\x46ieldOptions\x12\x41\n\x05\x63type\x18\x01 \x01(\x0e\x32#.google.protobuf.FieldOptions.CType:\x06STRINGR\x05\x63type\x12\x16\n\x06packed\x18\x02 \x01(\x08R\x06packed\x12G\n\x06jstype\x18\x06 \x01(\x0e\x32$.google.protobuf.FieldOptions.JSType:\tJS_NORMALR\x06jstype\x12\x19\n\x04lazy\x18\x05 \x01(\x08:\x05\x66\x61lseR\x04lazy\x12.\n\x0funverified_lazy\x18\x0f \x01(\x08:\x05\x66\x61lseR\x0eunverifiedLazy\x12%\n\ndeprecated\x18\x03 \x01(\x08:\x05\x66\x61lseR\ndeprecated\x12\x19\n\x04weak\x18\n \x01(\x08:\x05\x66\x61lseR\x04weak\x12(\n\x0c\x64\x65\x62ug_redact\x18\x10 \x01(\x08:\x05\x66\x61lseR\x0b\x64\x65\x62ugRedact\x12K\n\tretention\x18\x11 \x01(\x0e\x32-.google.protobuf.FieldOptions.OptionRetentionR\tretention\x12\x46\n\x06target\x18\x12 \x01(\x0e\x32..google.protobuf.FieldOptions.OptionTargetTypeR\x06target\x12X\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32$.google.protobuf.UninterpretedOptionR\x13uninterpretedOption"/\n\x05\x43Type\x12\n\n\x06STRING\x10\x00\x12\x08\n\x04\x43ORD\x10\x01\x12\x10\n\x0cSTRING_PIECE\x10\x02"5\n\x06JSType\x12\r\n\tJS_NORMAL\x10\x00\x12\r\n\tJS_STRING\x10\x01\x12\r\n\tJS_NUMBER\x10\x02"U\n\x0fOptionRetention\x12\x15\n\x11RETENTION_UNKNOWN\x10\x00\x12\x15\n\x11RETENTION_RUNTIME\x10\x01\x12\x14\n\x10RETENTION_SOURCE\x10\x02"\x8c\x02\n\x10OptionTargetType\x12\x17\n\x13TARGET_TYPE_UNKNOWN\x10\x00\x12\x14\n\x10TARGET_TYPE_FILE\x10\x01\x12\x1f\n\x1bTARGET_TYPE_EXTENSION_RANGE\x10\x02\x12\x17\n\x13TARGET_TYPE_MESSAGE\x10\x03\x12\x15\n\x11TARGET_TYPE_FIELD\x10\x04\x12\x15\n\x11TARGET_TYPE_ONEOF\x10\x05\x12\x14\n\x10TARGET_TYPE_ENUM\x10\x06\x12\x1a\n\x16TARGET_TYPE_ENUM_ENTRY\x10\x07\x12\x17\n\x13TARGET_TYPE_SERVICE\x10\x08\x12\x16\n\x12TARGET_TYPE_METHOD\x10\t*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02J\x04\x08\x04\x10\x05"s\n\x0cOneofOptions\x12X\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32$.google.protobuf.UninterpretedOptionR\x13uninterpretedOption*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02"\x98\x02\n\x0b\x45numOptions\x12\x1f\n\x0b\x61llow_alias\x18\x02 \x01(\x08R\nallowAlias\x12%\n\ndeprecated\x18\x03 \x01(\x08:\x05\x66\x61lseR\ndeprecated\x12V\n&deprecated_legacy_json_field_conflicts\x18\x06 \x01(\x08\x42\x02\x18\x01R"deprecatedLegacyJsonFieldConflicts\x12X\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32$.google.protobuf.UninterpretedOptionR\x13uninterpretedOption*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02J\x04\x08\x05\x10\x06"\x9e\x01\n\x10\x45numValueOptions\x12%\n\ndeprecated\x18\x01 \x01(\x08:\x05\x66\x61lseR\ndeprecated\x12X\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32$.google.protobuf.UninterpretedOptionR\x13uninterpretedOption*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02"\x9c\x01\n\x0eServiceOptions\x12%\n\ndeprecated\x18! \x01(\x08:\x05\x66\x61lseR\ndeprecated\x12X\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32$.google.protobuf.UninterpretedOptionR\x13uninterpretedOption*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02"\xe0\x02\n\rMethodOptions\x12%\n\ndeprecated\x18! \x01(\x08:\x05\x66\x61lseR\ndeprecated\x12q\n\x11idempotency_level\x18" \x01(\x0e\x32/.google.protobuf.MethodOptions.IdempotencyLevel:\x13IDEMPOTENCY_UNKNOWNR\x10idempotencyLevel\x12X\n\x14uninterpreted_option\x18\xe7\x07 \x03(\x0b\x32$.google.protobuf.UninterpretedOptionR\x13uninterpretedOption"P\n\x10IdempotencyLevel\x12\x17\n\x13IDEMPOTENCY_UNKNOWN\x10\x00\x12\x13\n\x0fNO_SIDE_EFFECTS\x10\x01\x12\x0e\n\nIDEMPOTENT\x10\x02*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02"\x9a\x03\n\x13UninterpretedOption\x12\x41\n\x04name\x18\x02 \x03(\x0b\x32-.google.protobuf.UninterpretedOption.NamePartR\x04name\x12)\n\x10identifier_value\x18\x03 \x01(\tR\x0fidentifierValue\x12,\n\x12positive_int_value\x18\x04 \x01(\x04R\x10positiveIntValue\x12,\n\x12negative_int_value\x18\x05 \x01(\x03R\x10negativeIntValue\x12!\n\x0c\x64ouble_value\x18\x06 \x01(\x01R\x0b\x64oubleValue\x12!\n\x0cstring_value\x18\x07 \x01(\x0cR\x0bstringValue\x12\'\n\x0f\x61ggregate_value\x18\x08 \x01(\tR\x0e\x61ggregateValue\x1aJ\n\x08NamePart\x12\x1b\n\tname_part\x18\x01 \x02(\tR\x08namePart\x12!\n\x0cis_extension\x18\x02 \x02(\x08R\x0bisExtension"\xa7\x02\n\x0eSourceCodeInfo\x12\x44\n\x08location\x18\x01 \x03(\x0b\x32(.google.protobuf.SourceCodeInfo.LocationR\x08location\x1a\xce\x01\n\x08Location\x12\x16\n\x04path\x18\x01 \x03(\x05\x42\x02\x10\x01R\x04path\x12\x16\n\x04span\x18\x02 \x03(\x05\x42\x02\x10\x01R\x04span\x12)\n\x10leading_comments\x18\x03 \x01(\tR\x0fleadingComments\x12+\n\x11trailing_comments\x18\x04 \x01(\tR\x10trailingComments\x12:\n\x19leading_detached_comments\x18\x06 \x03(\tR\x17leadingDetachedComments"\xd0\x02\n\x11GeneratedCodeInfo\x12M\n\nannotation\x18\x01 \x03(\x0b\x32-.google.protobuf.GeneratedCodeInfo.AnnotationR\nannotation\x1a\xeb\x01\n\nAnnotation\x12\x16\n\x04path\x18\x01 \x03(\x05\x42\x02\x10\x01R\x04path\x12\x1f\n\x0bsource_file\x18\x02 \x01(\tR\nsourceFile\x12\x14\n\x05\x62\x65gin\x18\x03 \x01(\x05R\x05\x62\x65gin\x12\x10\n\x03\x65nd\x18\x04 \x01(\x05R\x03\x65nd\x12R\n\x08semantic\x18\x05 \x01(\x0e\x32\x36.google.protobuf.GeneratedCodeInfo.Annotation.SemanticR\x08semantic"(\n\x08Semantic\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03SET\x10\x01\x12\t\n\x05\x41LIAS\x10\x02\x42~\n\x13\x63om.google.protobufB\x10\x44\x65scriptorProtosH\x01Z-google.golang.org/protobuf/types/descriptorpb\xf8\x01\x01\xa2\x02\x03GPB\xaa\x02\x1aGoogle.Protobuf.Reflection'
    )

_globals = globals()
if _descriptor._USE_C_DESCRIPTORS == False:
    _FIELDDESCRIPTORPROTO_TYPE = _descriptor.EnumDescriptor(
        name="Type",
        full_name="google.protobuf.FieldDescriptorProto.Type",
        filename=None,
        file=DESCRIPTOR,
        create_key=_descriptor._internal_create_key,
        values=[
            _descriptor.EnumValueDescriptor(
                name="TYPE_DOUBLE",
                index=0,
                number=1,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="TYPE_FLOAT",
                index=1,
                number=2,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="TYPE_INT64",
                index=2,
                number=3,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="TYPE_UINT64",
                index=3,
                number=4,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="TYPE_INT32",
                index=4,
                number=5,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="TYPE_FIXED64",
                index=5,
                number=6,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="TYPE_FIXED32",
                index=6,
                number=7,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="TYPE_BOOL",
                index=7,
                number=8,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="TYPE_STRING",
                index=8,
                number=9,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="TYPE_GROUP",
                index=9,
                number=10,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="TYPE_MESSAGE",
                index=10,
                number=11,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="TYPE_BYTES",
                index=11,
                number=12,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="TYPE_UINT32",
                index=12,
                number=13,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="TYPE_ENUM",
                index=13,
                number=14,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="TYPE_SFIXED32",
                index=14,
                number=15,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="TYPE_SFIXED64",
                index=15,
                number=16,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="TYPE_SINT32",
                index=16,
                number=17,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="TYPE_SINT64",
                index=17,
                number=18,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        containing_type=None,
        serialized_options=None,
    )
    _sym_db.RegisterEnumDescriptor(_FIELDDESCRIPTORPROTO_TYPE)

    _FIELDDESCRIPTORPROTO_LABEL = _descriptor.EnumDescriptor(
        name="Label",
        full_name="google.protobuf.FieldDescriptorProto.Label",
        filename=None,
        file=DESCRIPTOR,
        create_key=_descriptor._internal_create_key,
        values=[
            _descriptor.EnumValueDescriptor(
                name="LABEL_OPTIONAL",
                index=0,
                number=1,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="LABEL_REQUIRED",
                index=1,
                number=2,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="LABEL_REPEATED",
                index=2,
                number=3,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        containing_type=None,
        serialized_options=None,
    )
    _sym_db.RegisterEnumDescriptor(_FIELDDESCRIPTORPROTO_LABEL)

    _FILEOPTIONS_OPTIMIZEMODE = _descriptor.EnumDescriptor(
        name="OptimizeMode",
        full_name="google.protobuf.FileOptions.OptimizeMode",
        filename=None,
        file=DESCRIPTOR,
        create_key=_descriptor._internal_create_key,
        values=[
            _descriptor.EnumValueDescriptor(
                name="SPEED",
                index=0,
                number=1,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="CODE_SIZE",
                index=1,
                number=2,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="LITE_RUNTIME",
                index=2,
                number=3,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        containing_type=None,
        serialized_options=None,
    )
    _sym_db.RegisterEnumDescriptor(_FILEOPTIONS_OPTIMIZEMODE)

    _FIELDOPTIONS_CTYPE = _descriptor.EnumDescriptor(
        name="CType",
        full_name="google.protobuf.FieldOptions.CType",
        filename=None,
        file=DESCRIPTOR,
        create_key=_descriptor._internal_create_key,
        values=[
            _descriptor.EnumValueDescriptor(
                name="STRING",
                index=0,
                number=0,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="CORD",
                index=1,
                number=1,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="STRING_PIECE",
                index=2,
                number=2,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        containing_type=None,
        serialized_options=None,
    )
    _sym_db.RegisterEnumDescriptor(_FIELDOPTIONS_CTYPE)

    _FIELDOPTIONS_JSTYPE = _descriptor.EnumDescriptor(
        name="JSType",
        full_name="google.protobuf.FieldOptions.JSType",
        filename=None,
        file=DESCRIPTOR,
        create_key=_descriptor._internal_create_key,
        values=[
            _descriptor.EnumValueDescriptor(
                name="JS_NORMAL",
                index=0,
                number=0,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="JS_STRING",
                index=1,
                number=1,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="JS_NUMBER",
                index=2,
                number=2,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        containing_type=None,
        serialized_options=None,
    )
    _sym_db.RegisterEnumDescriptor(_FIELDOPTIONS_JSTYPE)

    _FIELDOPTIONS_OPTIONRETENTION = _descriptor.EnumDescriptor(
        name="OptionRetention",
        full_name="google.protobuf.FieldOptions.OptionRetention",
        filename=None,
        file=DESCRIPTOR,
        create_key=_descriptor._internal_create_key,
        values=[
            _descriptor.EnumValueDescriptor(
                name="RETENTION_UNKNOWN",
                index=0,
                number=0,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="RETENTION_RUNTIME",
                index=1,
                number=1,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="RETENTION_SOURCE",
                index=2,
                number=2,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        containing_type=None,
        serialized_options=None,
    )
    _sym_db.RegisterEnumDescriptor(_FIELDOPTIONS_OPTIONRETENTION)

    _FIELDOPTIONS_OPTIONTARGETTYPE = _descriptor.EnumDescriptor(
        name="OptionTargetType",
        full_name="google.protobuf.FieldOptions.OptionTargetType",
        filename=None,
        file=DESCRIPTOR,
        create_key=_descriptor._internal_create_key,
        values=[
            _descriptor.EnumValueDescriptor(
                name="TARGET_TYPE_UNKNOWN",
                index=0,
                number=0,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="TARGET_TYPE_FILE",
                index=1,
                number=1,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="TARGET_TYPE_EXTENSION_RANGE",
                index=2,
                number=2,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="TARGET_TYPE_MESSAGE",
                index=3,
                number=3,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="TARGET_TYPE_FIELD",
                index=4,
                number=4,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="TARGET_TYPE_ONEOF",
                index=5,
                number=5,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="TARGET_TYPE_ENUM",
                index=6,
                number=6,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="TARGET_TYPE_ENUM_ENTRY",
                index=7,
                number=7,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="TARGET_TYPE_SERVICE",
                index=8,
                number=8,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="TARGET_TYPE_METHOD",
                index=9,
                number=9,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        containing_type=None,
        serialized_options=None,
    )
    _sym_db.RegisterEnumDescriptor(_FIELDOPTIONS_OPTIONTARGETTYPE)

    _METHODOPTIONS_IDEMPOTENCYLEVEL = _descriptor.EnumDescriptor(
        name="IdempotencyLevel",
        full_name="google.protobuf.MethodOptions.IdempotencyLevel",
        filename=None,
        file=DESCRIPTOR,
        create_key=_descriptor._internal_create_key,
        values=[
            _descriptor.EnumValueDescriptor(
                name="IDEMPOTENCY_UNKNOWN",
                index=0,
                number=0,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="NO_SIDE_EFFECTS",
                index=1,
                number=1,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="IDEMPOTENT",
                index=2,
                number=2,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        containing_type=None,
        serialized_options=None,
    )
    _sym_db.RegisterEnumDescriptor(_METHODOPTIONS_IDEMPOTENCYLEVEL)

    _GENERATEDCODEINFO_ANNOTATION_SEMANTIC = _descriptor.EnumDescriptor(
        name="Semantic",
        full_name="google.protobuf.GeneratedCodeInfo.Annotation.Semantic",
        filename=None,
        file=DESCRIPTOR,
        create_key=_descriptor._internal_create_key,
        values=[
            _descriptor.EnumValueDescriptor(
                name="NONE",
                index=0,
                number=0,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="SET",
                index=1,
                number=1,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.EnumValueDescriptor(
                name="ALIAS",
                index=2,
                number=2,
                serialized_options=None,
                type=None,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        containing_type=None,
        serialized_options=None,
    )
    _sym_db.RegisterEnumDescriptor(_GENERATEDCODEINFO_ANNOTATION_SEMANTIC)

    _FILEDESCRIPTORSET = _descriptor.Descriptor(
        name="FileDescriptorSet",
        full_name="google.protobuf.FileDescriptorSet",
        filename=None,
        file=DESCRIPTOR,
        containing_type=None,
        create_key=_descriptor._internal_create_key,
        fields=[
            _descriptor.FieldDescriptor(
                name="file",
                full_name="google.protobuf.FileDescriptorSet.file",
                index=0,
                number=1,
                type=11,
                cpp_type=10,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="file",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        extensions=[],
        nested_types=[],
        enum_types=[],
        serialized_options=None,
        is_extendable=False,
        syntax="proto2",
        extension_ranges=[],
        oneofs=[],
    )

    _FILEDESCRIPTORPROTO = _descriptor.Descriptor(
        name="FileDescriptorProto",
        full_name="google.protobuf.FileDescriptorProto",
        filename=None,
        file=DESCRIPTOR,
        containing_type=None,
        create_key=_descriptor._internal_create_key,
        fields=[
            _descriptor.FieldDescriptor(
                name="name",
                full_name="google.protobuf.FileDescriptorProto.name",
                index=0,
                number=1,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="name",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="package",
                full_name="google.protobuf.FileDescriptorProto.package",
                index=1,
                number=2,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="package",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="dependency",
                full_name="google.protobuf.FileDescriptorProto.dependency",
                index=2,
                number=3,
                type=9,
                cpp_type=9,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="dependency",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="public_dependency",
                full_name="google.protobuf.FileDescriptorProto.public_dependency",
                index=3,
                number=10,
                type=5,
                cpp_type=1,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="publicDependency",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="weak_dependency",
                full_name="google.protobuf.FileDescriptorProto.weak_dependency",
                index=4,
                number=11,
                type=5,
                cpp_type=1,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="weakDependency",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="message_type",
                full_name="google.protobuf.FileDescriptorProto.message_type",
                index=5,
                number=4,
                type=11,
                cpp_type=10,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="messageType",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="enum_type",
                full_name="google.protobuf.FileDescriptorProto.enum_type",
                index=6,
                number=5,
                type=11,
                cpp_type=10,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="enumType",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="service",
                full_name="google.protobuf.FileDescriptorProto.service",
                index=7,
                number=6,
                type=11,
                cpp_type=10,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="service",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="extension",
                full_name="google.protobuf.FileDescriptorProto.extension",
                index=8,
                number=7,
                type=11,
                cpp_type=10,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="extension",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="options",
                full_name="google.protobuf.FileDescriptorProto.options",
                index=9,
                number=8,
                type=11,
                cpp_type=10,
                label=1,
                has_default_value=False,
                default_value=None,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="options",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="source_code_info",
                full_name="google.protobuf.FileDescriptorProto.source_code_info",
                index=10,
                number=9,
                type=11,
                cpp_type=10,
                label=1,
                has_default_value=False,
                default_value=None,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="sourceCodeInfo",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="syntax",
                full_name="google.protobuf.FileDescriptorProto.syntax",
                index=11,
                number=12,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="syntax",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="edition",
                full_name="google.protobuf.FileDescriptorProto.edition",
                index=12,
                number=13,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="edition",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        extensions=[],
        nested_types=[],
        enum_types=[],
        serialized_options=None,
        is_extendable=False,
        syntax="proto2",
        extension_ranges=[],
        oneofs=[],
    )

    _DESCRIPTORPROTO_EXTENSIONRANGE = _descriptor.Descriptor(
        name="ExtensionRange",
        full_name="google.protobuf.DescriptorProto.ExtensionRange",
        filename=None,
        file=DESCRIPTOR,
        containing_type=None,
        create_key=_descriptor._internal_create_key,
        fields=[
            _descriptor.FieldDescriptor(
                name="start",
                full_name="google.protobuf.DescriptorProto.ExtensionRange.start",
                index=0,
                number=1,
                type=5,
                cpp_type=1,
                label=1,
                has_default_value=False,
                default_value=0,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="start",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="end",
                full_name="google.protobuf.DescriptorProto.ExtensionRange.end",
                index=1,
                number=2,
                type=5,
                cpp_type=1,
                label=1,
                has_default_value=False,
                default_value=0,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="end",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="options",
                full_name="google.protobuf.DescriptorProto.ExtensionRange.options",
                index=2,
                number=3,
                type=11,
                cpp_type=10,
                label=1,
                has_default_value=False,
                default_value=None,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="options",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        extensions=[],
        nested_types=[],
        enum_types=[],
        serialized_options=None,
        is_extendable=False,
        syntax="proto2",
        extension_ranges=[],
        oneofs=[],
    )

    _DESCRIPTORPROTO_RESERVEDRANGE = _descriptor.Descriptor(
        name="ReservedRange",
        full_name="google.protobuf.DescriptorProto.ReservedRange",
        filename=None,
        file=DESCRIPTOR,
        containing_type=None,
        create_key=_descriptor._internal_create_key,
        fields=[
            _descriptor.FieldDescriptor(
                name="start",
                full_name="google.protobuf.DescriptorProto.ReservedRange.start",
                index=0,
                number=1,
                type=5,
                cpp_type=1,
                label=1,
                has_default_value=False,
                default_value=0,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="start",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="end",
                full_name="google.protobuf.DescriptorProto.ReservedRange.end",
                index=1,
                number=2,
                type=5,
                cpp_type=1,
                label=1,
                has_default_value=False,
                default_value=0,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="end",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        extensions=[],
        nested_types=[],
        enum_types=[],
        serialized_options=None,
        is_extendable=False,
        syntax="proto2",
        extension_ranges=[],
        oneofs=[],
    )

    _DESCRIPTORPROTO = _descriptor.Descriptor(
        name="DescriptorProto",
        full_name="google.protobuf.DescriptorProto",
        filename=None,
        file=DESCRIPTOR,
        containing_type=None,
        create_key=_descriptor._internal_create_key,
        fields=[
            _descriptor.FieldDescriptor(
                name="name",
                full_name="google.protobuf.DescriptorProto.name",
                index=0,
                number=1,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="name",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="field",
                full_name="google.protobuf.DescriptorProto.field",
                index=1,
                number=2,
                type=11,
                cpp_type=10,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="field",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="extension",
                full_name="google.protobuf.DescriptorProto.extension",
                index=2,
                number=6,
                type=11,
                cpp_type=10,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="extension",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="nested_type",
                full_name="google.protobuf.DescriptorProto.nested_type",
                index=3,
                number=3,
                type=11,
                cpp_type=10,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="nestedType",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="enum_type",
                full_name="google.protobuf.DescriptorProto.enum_type",
                index=4,
                number=4,
                type=11,
                cpp_type=10,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="enumType",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="extension_range",
                full_name="google.protobuf.DescriptorProto.extension_range",
                index=5,
                number=5,
                type=11,
                cpp_type=10,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="extensionRange",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="oneof_decl",
                full_name="google.protobuf.DescriptorProto.oneof_decl",
                index=6,
                number=8,
                type=11,
                cpp_type=10,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="oneofDecl",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="options",
                full_name="google.protobuf.DescriptorProto.options",
                index=7,
                number=7,
                type=11,
                cpp_type=10,
                label=1,
                has_default_value=False,
                default_value=None,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="options",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="reserved_range",
                full_name="google.protobuf.DescriptorProto.reserved_range",
                index=8,
                number=9,
                type=11,
                cpp_type=10,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="reservedRange",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="reserved_name",
                full_name="google.protobuf.DescriptorProto.reserved_name",
                index=9,
                number=10,
                type=9,
                cpp_type=9,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="reservedName",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        extensions=[],
        nested_types=[
            _DESCRIPTORPROTO_EXTENSIONRANGE,
            _DESCRIPTORPROTO_RESERVEDRANGE,
        ],
        enum_types=[],
        serialized_options=None,
        is_extendable=False,
        syntax="proto2",
        extension_ranges=[],
        oneofs=[],
    )

    _EXTENSIONRANGEOPTIONS = _descriptor.Descriptor(
        name="ExtensionRangeOptions",
        full_name="google.protobuf.ExtensionRangeOptions",
        filename=None,
        file=DESCRIPTOR,
        containing_type=None,
        create_key=_descriptor._internal_create_key,
        fields=[
            _descriptor.FieldDescriptor(
                name="uninterpreted_option",
                full_name="google.protobuf.ExtensionRangeOptions.uninterpreted_option",
                index=0,
                number=999,
                type=11,
                cpp_type=10,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="uninterpretedOption",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        extensions=[],
        nested_types=[],
        enum_types=[],
        serialized_options=None,
        is_extendable=True,
        syntax="proto2",
        extension_ranges=[
            (1000, 536870912),
        ],
        oneofs=[],
    )

    _FIELDDESCRIPTORPROTO = _descriptor.Descriptor(
        name="FieldDescriptorProto",
        full_name="google.protobuf.FieldDescriptorProto",
        filename=None,
        file=DESCRIPTOR,
        containing_type=None,
        create_key=_descriptor._internal_create_key,
        fields=[
            _descriptor.FieldDescriptor(
                name="name",
                full_name="google.protobuf.FieldDescriptorProto.name",
                index=0,
                number=1,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="name",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="number",
                full_name="google.protobuf.FieldDescriptorProto.number",
                index=1,
                number=3,
                type=5,
                cpp_type=1,
                label=1,
                has_default_value=False,
                default_value=0,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="number",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="label",
                full_name="google.protobuf.FieldDescriptorProto.label",
                index=2,
                number=4,
                type=14,
                cpp_type=8,
                label=1,
                has_default_value=False,
                default_value=1,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="label",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="type",
                full_name="google.protobuf.FieldDescriptorProto.type",
                index=3,
                number=5,
                type=14,
                cpp_type=8,
                label=1,
                has_default_value=False,
                default_value=1,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="type",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="type_name",
                full_name="google.protobuf.FieldDescriptorProto.type_name",
                index=4,
                number=6,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="typeName",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="extendee",
                full_name="google.protobuf.FieldDescriptorProto.extendee",
                index=5,
                number=2,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="extendee",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="default_value",
                full_name="google.protobuf.FieldDescriptorProto.default_value",
                index=6,
                number=7,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="defaultValue",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="oneof_index",
                full_name="google.protobuf.FieldDescriptorProto.oneof_index",
                index=7,
                number=9,
                type=5,
                cpp_type=1,
                label=1,
                has_default_value=False,
                default_value=0,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="oneofIndex",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="json_name",
                full_name="google.protobuf.FieldDescriptorProto.json_name",
                index=8,
                number=10,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="jsonName",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="options",
                full_name="google.protobuf.FieldDescriptorProto.options",
                index=9,
                number=8,
                type=11,
                cpp_type=10,
                label=1,
                has_default_value=False,
                default_value=None,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="options",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="proto3_optional",
                full_name="google.protobuf.FieldDescriptorProto.proto3_optional",
                index=10,
                number=17,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=False,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="proto3Optional",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        extensions=[],
        nested_types=[],
        enum_types=[
            _FIELDDESCRIPTORPROTO_TYPE,
            _FIELDDESCRIPTORPROTO_LABEL,
        ],
        serialized_options=None,
        is_extendable=False,
        syntax="proto2",
        extension_ranges=[],
        oneofs=[],
    )

    _ONEOFDESCRIPTORPROTO = _descriptor.Descriptor(
        name="OneofDescriptorProto",
        full_name="google.protobuf.OneofDescriptorProto",
        filename=None,
        file=DESCRIPTOR,
        containing_type=None,
        create_key=_descriptor._internal_create_key,
        fields=[
            _descriptor.FieldDescriptor(
                name="name",
                full_name="google.protobuf.OneofDescriptorProto.name",
                index=0,
                number=1,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="name",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="options",
                full_name="google.protobuf.OneofDescriptorProto.options",
                index=1,
                number=2,
                type=11,
                cpp_type=10,
                label=1,
                has_default_value=False,
                default_value=None,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="options",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        extensions=[],
        nested_types=[],
        enum_types=[],
        serialized_options=None,
        is_extendable=False,
        syntax="proto2",
        extension_ranges=[],
        oneofs=[],
    )

    _ENUMDESCRIPTORPROTO_ENUMRESERVEDRANGE = _descriptor.Descriptor(
        name="EnumReservedRange",
        full_name="google.protobuf.EnumDescriptorProto.EnumReservedRange",
        filename=None,
        file=DESCRIPTOR,
        containing_type=None,
        create_key=_descriptor._internal_create_key,
        fields=[
            _descriptor.FieldDescriptor(
                name="start",
                full_name="google.protobuf.EnumDescriptorProto.EnumReservedRange.start",
                index=0,
                number=1,
                type=5,
                cpp_type=1,
                label=1,
                has_default_value=False,
                default_value=0,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="start",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="end",
                full_name="google.protobuf.EnumDescriptorProto.EnumReservedRange.end",
                index=1,
                number=2,
                type=5,
                cpp_type=1,
                label=1,
                has_default_value=False,
                default_value=0,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="end",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        extensions=[],
        nested_types=[],
        enum_types=[],
        serialized_options=None,
        is_extendable=False,
        syntax="proto2",
        extension_ranges=[],
        oneofs=[],
    )

    _ENUMDESCRIPTORPROTO = _descriptor.Descriptor(
        name="EnumDescriptorProto",
        full_name="google.protobuf.EnumDescriptorProto",
        filename=None,
        file=DESCRIPTOR,
        containing_type=None,
        create_key=_descriptor._internal_create_key,
        fields=[
            _descriptor.FieldDescriptor(
                name="name",
                full_name="google.protobuf.EnumDescriptorProto.name",
                index=0,
                number=1,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="name",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="value",
                full_name="google.protobuf.EnumDescriptorProto.value",
                index=1,
                number=2,
                type=11,
                cpp_type=10,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="value",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="options",
                full_name="google.protobuf.EnumDescriptorProto.options",
                index=2,
                number=3,
                type=11,
                cpp_type=10,
                label=1,
                has_default_value=False,
                default_value=None,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="options",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="reserved_range",
                full_name="google.protobuf.EnumDescriptorProto.reserved_range",
                index=3,
                number=4,
                type=11,
                cpp_type=10,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="reservedRange",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="reserved_name",
                full_name="google.protobuf.EnumDescriptorProto.reserved_name",
                index=4,
                number=5,
                type=9,
                cpp_type=9,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="reservedName",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        extensions=[],
        nested_types=[
            _ENUMDESCRIPTORPROTO_ENUMRESERVEDRANGE,
        ],
        enum_types=[],
        serialized_options=None,
        is_extendable=False,
        syntax="proto2",
        extension_ranges=[],
        oneofs=[],
    )

    _ENUMVALUEDESCRIPTORPROTO = _descriptor.Descriptor(
        name="EnumValueDescriptorProto",
        full_name="google.protobuf.EnumValueDescriptorProto",
        filename=None,
        file=DESCRIPTOR,
        containing_type=None,
        create_key=_descriptor._internal_create_key,
        fields=[
            _descriptor.FieldDescriptor(
                name="name",
                full_name="google.protobuf.EnumValueDescriptorProto.name",
                index=0,
                number=1,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="name",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="number",
                full_name="google.protobuf.EnumValueDescriptorProto.number",
                index=1,
                number=2,
                type=5,
                cpp_type=1,
                label=1,
                has_default_value=False,
                default_value=0,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="number",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="options",
                full_name="google.protobuf.EnumValueDescriptorProto.options",
                index=2,
                number=3,
                type=11,
                cpp_type=10,
                label=1,
                has_default_value=False,
                default_value=None,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="options",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        extensions=[],
        nested_types=[],
        enum_types=[],
        serialized_options=None,
        is_extendable=False,
        syntax="proto2",
        extension_ranges=[],
        oneofs=[],
    )

    _SERVICEDESCRIPTORPROTO = _descriptor.Descriptor(
        name="ServiceDescriptorProto",
        full_name="google.protobuf.ServiceDescriptorProto",
        filename=None,
        file=DESCRIPTOR,
        containing_type=None,
        create_key=_descriptor._internal_create_key,
        fields=[
            _descriptor.FieldDescriptor(
                name="name",
                full_name="google.protobuf.ServiceDescriptorProto.name",
                index=0,
                number=1,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="name",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="method",
                full_name="google.protobuf.ServiceDescriptorProto.method",
                index=1,
                number=2,
                type=11,
                cpp_type=10,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="method",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="options",
                full_name="google.protobuf.ServiceDescriptorProto.options",
                index=2,
                number=3,
                type=11,
                cpp_type=10,
                label=1,
                has_default_value=False,
                default_value=None,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="options",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        extensions=[],
        nested_types=[],
        enum_types=[],
        serialized_options=None,
        is_extendable=False,
        syntax="proto2",
        extension_ranges=[],
        oneofs=[],
    )

    _METHODDESCRIPTORPROTO = _descriptor.Descriptor(
        name="MethodDescriptorProto",
        full_name="google.protobuf.MethodDescriptorProto",
        filename=None,
        file=DESCRIPTOR,
        containing_type=None,
        create_key=_descriptor._internal_create_key,
        fields=[
            _descriptor.FieldDescriptor(
                name="name",
                full_name="google.protobuf.MethodDescriptorProto.name",
                index=0,
                number=1,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="name",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="input_type",
                full_name="google.protobuf.MethodDescriptorProto.input_type",
                index=1,
                number=2,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="inputType",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="output_type",
                full_name="google.protobuf.MethodDescriptorProto.output_type",
                index=2,
                number=3,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="outputType",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="options",
                full_name="google.protobuf.MethodDescriptorProto.options",
                index=3,
                number=4,
                type=11,
                cpp_type=10,
                label=1,
                has_default_value=False,
                default_value=None,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="options",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="client_streaming",
                full_name="google.protobuf.MethodDescriptorProto.client_streaming",
                index=4,
                number=5,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=True,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="clientStreaming",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="server_streaming",
                full_name="google.protobuf.MethodDescriptorProto.server_streaming",
                index=5,
                number=6,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=True,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="serverStreaming",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        extensions=[],
        nested_types=[],
        enum_types=[],
        serialized_options=None,
        is_extendable=False,
        syntax="proto2",
        extension_ranges=[],
        oneofs=[],
    )

    _FILEOPTIONS = _descriptor.Descriptor(
        name="FileOptions",
        full_name="google.protobuf.FileOptions",
        filename=None,
        file=DESCRIPTOR,
        containing_type=None,
        create_key=_descriptor._internal_create_key,
        fields=[
            _descriptor.FieldDescriptor(
                name="java_package",
                full_name="google.protobuf.FileOptions.java_package",
                index=0,
                number=1,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="javaPackage",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="java_outer_classname",
                full_name="google.protobuf.FileOptions.java_outer_classname",
                index=1,
                number=8,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="javaOuterClassname",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="java_multiple_files",
                full_name="google.protobuf.FileOptions.java_multiple_files",
                index=2,
                number=10,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=True,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="javaMultipleFiles",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="java_generate_equals_and_hash",
                full_name="google.protobuf.FileOptions.java_generate_equals_and_hash",
                index=3,
                number=20,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=False,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="javaGenerateEqualsAndHash",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="java_string_check_utf8",
                full_name="google.protobuf.FileOptions.java_string_check_utf8",
                index=4,
                number=27,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=True,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="javaStringCheckUtf8",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="optimize_for",
                full_name="google.protobuf.FileOptions.optimize_for",
                index=5,
                number=9,
                type=14,
                cpp_type=8,
                label=1,
                has_default_value=True,
                default_value=1,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="optimizeFor",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="go_package",
                full_name="google.protobuf.FileOptions.go_package",
                index=6,
                number=11,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="goPackage",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="cc_generic_services",
                full_name="google.protobuf.FileOptions.cc_generic_services",
                index=7,
                number=16,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=True,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="ccGenericServices",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="java_generic_services",
                full_name="google.protobuf.FileOptions.java_generic_services",
                index=8,
                number=17,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=True,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="javaGenericServices",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="py_generic_services",
                full_name="google.protobuf.FileOptions.py_generic_services",
                index=9,
                number=18,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=True,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="pyGenericServices",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="php_generic_services",
                full_name="google.protobuf.FileOptions.php_generic_services",
                index=10,
                number=42,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=True,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="phpGenericServices",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="deprecated",
                full_name="google.protobuf.FileOptions.deprecated",
                index=11,
                number=23,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=True,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="deprecated",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="cc_enable_arenas",
                full_name="google.protobuf.FileOptions.cc_enable_arenas",
                index=12,
                number=31,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=True,
                default_value=True,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="ccEnableArenas",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="objc_class_prefix",
                full_name="google.protobuf.FileOptions.objc_class_prefix",
                index=13,
                number=36,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="objcClassPrefix",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="csharp_namespace",
                full_name="google.protobuf.FileOptions.csharp_namespace",
                index=14,
                number=37,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="csharpNamespace",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="swift_prefix",
                full_name="google.protobuf.FileOptions.swift_prefix",
                index=15,
                number=39,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="swiftPrefix",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="php_class_prefix",
                full_name="google.protobuf.FileOptions.php_class_prefix",
                index=16,
                number=40,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="phpClassPrefix",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="php_namespace",
                full_name="google.protobuf.FileOptions.php_namespace",
                index=17,
                number=41,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="phpNamespace",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="php_metadata_namespace",
                full_name="google.protobuf.FileOptions.php_metadata_namespace",
                index=18,
                number=44,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="phpMetadataNamespace",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="ruby_package",
                full_name="google.protobuf.FileOptions.ruby_package",
                index=19,
                number=45,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="rubyPackage",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="uninterpreted_option",
                full_name="google.protobuf.FileOptions.uninterpreted_option",
                index=20,
                number=999,
                type=11,
                cpp_type=10,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="uninterpretedOption",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        extensions=[],
        nested_types=[],
        enum_types=[
            _FILEOPTIONS_OPTIMIZEMODE,
        ],
        serialized_options=None,
        is_extendable=True,
        syntax="proto2",
        extension_ranges=[
            (1000, 536870912),
        ],
        oneofs=[],
    )

    _MESSAGEOPTIONS = _descriptor.Descriptor(
        name="MessageOptions",
        full_name="google.protobuf.MessageOptions",
        filename=None,
        file=DESCRIPTOR,
        containing_type=None,
        create_key=_descriptor._internal_create_key,
        fields=[
            _descriptor.FieldDescriptor(
                name="message_set_wire_format",
                full_name="google.protobuf.MessageOptions.message_set_wire_format",
                index=0,
                number=1,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=True,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="messageSetWireFormat",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="no_standard_descriptor_accessor",
                full_name="google.protobuf.MessageOptions.no_standard_descriptor_accessor",
                index=1,
                number=2,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=True,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="noStandardDescriptorAccessor",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="deprecated",
                full_name="google.protobuf.MessageOptions.deprecated",
                index=2,
                number=3,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=True,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="deprecated",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="map_entry",
                full_name="google.protobuf.MessageOptions.map_entry",
                index=3,
                number=7,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=False,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="mapEntry",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="deprecated_legacy_json_field_conflicts",
                full_name="google.protobuf.MessageOptions.deprecated_legacy_json_field_conflicts",
                index=4,
                number=11,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=False,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="deprecatedLegacyJsonFieldConflicts",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="uninterpreted_option",
                full_name="google.protobuf.MessageOptions.uninterpreted_option",
                index=5,
                number=999,
                type=11,
                cpp_type=10,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="uninterpretedOption",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        extensions=[],
        nested_types=[],
        enum_types=[],
        serialized_options=None,
        is_extendable=True,
        syntax="proto2",
        extension_ranges=[
            (1000, 536870912),
        ],
        oneofs=[],
    )

    _FIELDOPTIONS = _descriptor.Descriptor(
        name="FieldOptions",
        full_name="google.protobuf.FieldOptions",
        filename=None,
        file=DESCRIPTOR,
        containing_type=None,
        create_key=_descriptor._internal_create_key,
        fields=[
            _descriptor.FieldDescriptor(
                name="ctype",
                full_name="google.protobuf.FieldOptions.ctype",
                index=0,
                number=1,
                type=14,
                cpp_type=8,
                label=1,
                has_default_value=True,
                default_value=0,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="ctype",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="packed",
                full_name="google.protobuf.FieldOptions.packed",
                index=1,
                number=2,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=False,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="packed",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="jstype",
                full_name="google.protobuf.FieldOptions.jstype",
                index=2,
                number=6,
                type=14,
                cpp_type=8,
                label=1,
                has_default_value=True,
                default_value=0,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="jstype",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="lazy",
                full_name="google.protobuf.FieldOptions.lazy",
                index=3,
                number=5,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=True,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="lazy",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="unverified_lazy",
                full_name="google.protobuf.FieldOptions.unverified_lazy",
                index=4,
                number=15,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=True,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="unverifiedLazy",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="deprecated",
                full_name="google.protobuf.FieldOptions.deprecated",
                index=5,
                number=3,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=True,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="deprecated",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="weak",
                full_name="google.protobuf.FieldOptions.weak",
                index=6,
                number=10,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=True,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="weak",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="debug_redact",
                full_name="google.protobuf.FieldOptions.debug_redact",
                index=7,
                number=16,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=True,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="debugRedact",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="retention",
                full_name="google.protobuf.FieldOptions.retention",
                index=8,
                number=17,
                type=14,
                cpp_type=8,
                label=1,
                has_default_value=False,
                default_value=0,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="retention",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="target",
                full_name="google.protobuf.FieldOptions.target",
                index=9,
                number=18,
                type=14,
                cpp_type=8,
                label=1,
                has_default_value=False,
                default_value=0,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="target",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="uninterpreted_option",
                full_name="google.protobuf.FieldOptions.uninterpreted_option",
                index=10,
                number=999,
                type=11,
                cpp_type=10,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="uninterpretedOption",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        extensions=[],
        nested_types=[],
        enum_types=[
            _FIELDOPTIONS_CTYPE,
            _FIELDOPTIONS_JSTYPE,
            _FIELDOPTIONS_OPTIONRETENTION,
            _FIELDOPTIONS_OPTIONTARGETTYPE,
        ],
        serialized_options=None,
        is_extendable=True,
        syntax="proto2",
        extension_ranges=[
            (1000, 536870912),
        ],
        oneofs=[],
    )

    _ONEOFOPTIONS = _descriptor.Descriptor(
        name="OneofOptions",
        full_name="google.protobuf.OneofOptions",
        filename=None,
        file=DESCRIPTOR,
        containing_type=None,
        create_key=_descriptor._internal_create_key,
        fields=[
            _descriptor.FieldDescriptor(
                name="uninterpreted_option",
                full_name="google.protobuf.OneofOptions.uninterpreted_option",
                index=0,
                number=999,
                type=11,
                cpp_type=10,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="uninterpretedOption",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        extensions=[],
        nested_types=[],
        enum_types=[],
        serialized_options=None,
        is_extendable=True,
        syntax="proto2",
        extension_ranges=[
            (1000, 536870912),
        ],
        oneofs=[],
    )

    _ENUMOPTIONS = _descriptor.Descriptor(
        name="EnumOptions",
        full_name="google.protobuf.EnumOptions",
        filename=None,
        file=DESCRIPTOR,
        containing_type=None,
        create_key=_descriptor._internal_create_key,
        fields=[
            _descriptor.FieldDescriptor(
                name="allow_alias",
                full_name="google.protobuf.EnumOptions.allow_alias",
                index=0,
                number=2,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=False,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="allowAlias",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="deprecated",
                full_name="google.protobuf.EnumOptions.deprecated",
                index=1,
                number=3,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=True,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="deprecated",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="deprecated_legacy_json_field_conflicts",
                full_name="google.protobuf.EnumOptions.deprecated_legacy_json_field_conflicts",
                index=2,
                number=6,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=False,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="deprecatedLegacyJsonFieldConflicts",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="uninterpreted_option",
                full_name="google.protobuf.EnumOptions.uninterpreted_option",
                index=3,
                number=999,
                type=11,
                cpp_type=10,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="uninterpretedOption",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        extensions=[],
        nested_types=[],
        enum_types=[],
        serialized_options=None,
        is_extendable=True,
        syntax="proto2",
        extension_ranges=[
            (1000, 536870912),
        ],
        oneofs=[],
    )

    _ENUMVALUEOPTIONS = _descriptor.Descriptor(
        name="EnumValueOptions",
        full_name="google.protobuf.EnumValueOptions",
        filename=None,
        file=DESCRIPTOR,
        containing_type=None,
        create_key=_descriptor._internal_create_key,
        fields=[
            _descriptor.FieldDescriptor(
                name="deprecated",
                full_name="google.protobuf.EnumValueOptions.deprecated",
                index=0,
                number=1,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=True,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="deprecated",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="uninterpreted_option",
                full_name="google.protobuf.EnumValueOptions.uninterpreted_option",
                index=1,
                number=999,
                type=11,
                cpp_type=10,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="uninterpretedOption",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        extensions=[],
        nested_types=[],
        enum_types=[],
        serialized_options=None,
        is_extendable=True,
        syntax="proto2",
        extension_ranges=[
            (1000, 536870912),
        ],
        oneofs=[],
    )

    _SERVICEOPTIONS = _descriptor.Descriptor(
        name="ServiceOptions",
        full_name="google.protobuf.ServiceOptions",
        filename=None,
        file=DESCRIPTOR,
        containing_type=None,
        create_key=_descriptor._internal_create_key,
        fields=[
            _descriptor.FieldDescriptor(
                name="deprecated",
                full_name="google.protobuf.ServiceOptions.deprecated",
                index=0,
                number=33,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=True,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="deprecated",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="uninterpreted_option",
                full_name="google.protobuf.ServiceOptions.uninterpreted_option",
                index=1,
                number=999,
                type=11,
                cpp_type=10,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="uninterpretedOption",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        extensions=[],
        nested_types=[],
        enum_types=[],
        serialized_options=None,
        is_extendable=True,
        syntax="proto2",
        extension_ranges=[
            (1000, 536870912),
        ],
        oneofs=[],
    )

    _METHODOPTIONS = _descriptor.Descriptor(
        name="MethodOptions",
        full_name="google.protobuf.MethodOptions",
        filename=None,
        file=DESCRIPTOR,
        containing_type=None,
        create_key=_descriptor._internal_create_key,
        fields=[
            _descriptor.FieldDescriptor(
                name="deprecated",
                full_name="google.protobuf.MethodOptions.deprecated",
                index=0,
                number=33,
                type=8,
                cpp_type=7,
                label=1,
                has_default_value=True,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="deprecated",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="idempotency_level",
                full_name="google.protobuf.MethodOptions.idempotency_level",
                index=1,
                number=34,
                type=14,
                cpp_type=8,
                label=1,
                has_default_value=True,
                default_value=0,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="idempotencyLevel",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="uninterpreted_option",
                full_name="google.protobuf.MethodOptions.uninterpreted_option",
                index=2,
                number=999,
                type=11,
                cpp_type=10,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="uninterpretedOption",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        extensions=[],
        nested_types=[],
        enum_types=[
            _METHODOPTIONS_IDEMPOTENCYLEVEL,
        ],
        serialized_options=None,
        is_extendable=True,
        syntax="proto2",
        extension_ranges=[
            (1000, 536870912),
        ],
        oneofs=[],
    )

    _UNINTERPRETEDOPTION_NAMEPART = _descriptor.Descriptor(
        name="NamePart",
        full_name="google.protobuf.UninterpretedOption.NamePart",
        filename=None,
        file=DESCRIPTOR,
        containing_type=None,
        create_key=_descriptor._internal_create_key,
        fields=[
            _descriptor.FieldDescriptor(
                name="name_part",
                full_name="google.protobuf.UninterpretedOption.NamePart.name_part",
                index=0,
                number=1,
                type=9,
                cpp_type=9,
                label=2,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="namePart",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="is_extension",
                full_name="google.protobuf.UninterpretedOption.NamePart.is_extension",
                index=1,
                number=2,
                type=8,
                cpp_type=7,
                label=2,
                has_default_value=False,
                default_value=False,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="isExtension",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        extensions=[],
        nested_types=[],
        enum_types=[],
        serialized_options=None,
        is_extendable=False,
        syntax="proto2",
        extension_ranges=[],
        oneofs=[],
    )

    _UNINTERPRETEDOPTION = _descriptor.Descriptor(
        name="UninterpretedOption",
        full_name="google.protobuf.UninterpretedOption",
        filename=None,
        file=DESCRIPTOR,
        containing_type=None,
        create_key=_descriptor._internal_create_key,
        fields=[
            _descriptor.FieldDescriptor(
                name="name",
                full_name="google.protobuf.UninterpretedOption.name",
                index=0,
                number=2,
                type=11,
                cpp_type=10,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="name",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="identifier_value",
                full_name="google.protobuf.UninterpretedOption.identifier_value",
                index=1,
                number=3,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="identifierValue",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="positive_int_value",
                full_name="google.protobuf.UninterpretedOption.positive_int_value",
                index=2,
                number=4,
                type=4,
                cpp_type=4,
                label=1,
                has_default_value=False,
                default_value=0,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="positiveIntValue",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="negative_int_value",
                full_name="google.protobuf.UninterpretedOption.negative_int_value",
                index=3,
                number=5,
                type=3,
                cpp_type=2,
                label=1,
                has_default_value=False,
                default_value=0,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="negativeIntValue",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="double_value",
                full_name="google.protobuf.UninterpretedOption.double_value",
                index=4,
                number=6,
                type=1,
                cpp_type=5,
                label=1,
                has_default_value=False,
                default_value=float(0),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="doubleValue",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="string_value",
                full_name="google.protobuf.UninterpretedOption.string_value",
                index=5,
                number=7,
                type=12,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"",
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="stringValue",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="aggregate_value",
                full_name="google.protobuf.UninterpretedOption.aggregate_value",
                index=6,
                number=8,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="aggregateValue",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        extensions=[],
        nested_types=[
            _UNINTERPRETEDOPTION_NAMEPART,
        ],
        enum_types=[],
        serialized_options=None,
        is_extendable=False,
        syntax="proto2",
        extension_ranges=[],
        oneofs=[],
    )

    _SOURCECODEINFO_LOCATION = _descriptor.Descriptor(
        name="Location",
        full_name="google.protobuf.SourceCodeInfo.Location",
        filename=None,
        file=DESCRIPTOR,
        containing_type=None,
        create_key=_descriptor._internal_create_key,
        fields=[
            _descriptor.FieldDescriptor(
                name="path",
                full_name="google.protobuf.SourceCodeInfo.Location.path",
                index=0,
                number=1,
                type=5,
                cpp_type=1,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="path",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="span",
                full_name="google.protobuf.SourceCodeInfo.Location.span",
                index=1,
                number=2,
                type=5,
                cpp_type=1,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="span",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="leading_comments",
                full_name="google.protobuf.SourceCodeInfo.Location.leading_comments",
                index=2,
                number=3,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="leadingComments",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="trailing_comments",
                full_name="google.protobuf.SourceCodeInfo.Location.trailing_comments",
                index=3,
                number=4,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="trailingComments",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="leading_detached_comments",
                full_name="google.protobuf.SourceCodeInfo.Location.leading_detached_comments",
                index=4,
                number=6,
                type=9,
                cpp_type=9,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="leadingDetachedComments",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        extensions=[],
        nested_types=[],
        enum_types=[],
        serialized_options=None,
        is_extendable=False,
        syntax="proto2",
        extension_ranges=[],
        oneofs=[],
    )

    _SOURCECODEINFO = _descriptor.Descriptor(
        name="SourceCodeInfo",
        full_name="google.protobuf.SourceCodeInfo",
        filename=None,
        file=DESCRIPTOR,
        containing_type=None,
        create_key=_descriptor._internal_create_key,
        fields=[
            _descriptor.FieldDescriptor(
                name="location",
                full_name="google.protobuf.SourceCodeInfo.location",
                index=0,
                number=1,
                type=11,
                cpp_type=10,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="location",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        extensions=[],
        nested_types=[
            _SOURCECODEINFO_LOCATION,
        ],
        enum_types=[],
        serialized_options=None,
        is_extendable=False,
        syntax="proto2",
        extension_ranges=[],
        oneofs=[],
    )

    _GENERATEDCODEINFO_ANNOTATION = _descriptor.Descriptor(
        name="Annotation",
        full_name="google.protobuf.GeneratedCodeInfo.Annotation",
        filename=None,
        file=DESCRIPTOR,
        containing_type=None,
        create_key=_descriptor._internal_create_key,
        fields=[
            _descriptor.FieldDescriptor(
                name="path",
                full_name="google.protobuf.GeneratedCodeInfo.Annotation.path",
                index=0,
                number=1,
                type=5,
                cpp_type=1,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="path",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="source_file",
                full_name="google.protobuf.GeneratedCodeInfo.Annotation.source_file",
                index=1,
                number=2,
                type=9,
                cpp_type=9,
                label=1,
                has_default_value=False,
                default_value=b"".decode("utf-8"),
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="sourceFile",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="begin",
                full_name="google.protobuf.GeneratedCodeInfo.Annotation.begin",
                index=2,
                number=3,
                type=5,
                cpp_type=1,
                label=1,
                has_default_value=False,
                default_value=0,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="begin",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="end",
                full_name="google.protobuf.GeneratedCodeInfo.Annotation.end",
                index=3,
                number=4,
                type=5,
                cpp_type=1,
                label=1,
                has_default_value=False,
                default_value=0,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="end",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
            _descriptor.FieldDescriptor(
                name="semantic",
                full_name="google.protobuf.GeneratedCodeInfo.Annotation.semantic",
                index=4,
                number=5,
                type=14,
                cpp_type=8,
                label=1,
                has_default_value=False,
                default_value=0,
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="semantic",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        extensions=[],
        nested_types=[],
        enum_types=[
            _GENERATEDCODEINFO_ANNOTATION_SEMANTIC,
        ],
        serialized_options=None,
        is_extendable=False,
        syntax="proto2",
        extension_ranges=[],
        oneofs=[],
    )

    _GENERATEDCODEINFO = _descriptor.Descriptor(
        name="GeneratedCodeInfo",
        full_name="google.protobuf.GeneratedCodeInfo",
        filename=None,
        file=DESCRIPTOR,
        containing_type=None,
        create_key=_descriptor._internal_create_key,
        fields=[
            _descriptor.FieldDescriptor(
                name="annotation",
                full_name="google.protobuf.GeneratedCodeInfo.annotation",
                index=0,
                number=1,
                type=11,
                cpp_type=10,
                label=3,
                has_default_value=False,
                default_value=[],
                message_type=None,
                enum_type=None,
                containing_type=None,
                is_extension=False,
                extension_scope=None,
                serialized_options=None,
                json_name="annotation",
                file=DESCRIPTOR,
                create_key=_descriptor._internal_create_key,
            ),
        ],
        extensions=[],
        nested_types=[
            _GENERATEDCODEINFO_ANNOTATION,
        ],
        enum_types=[],
        serialized_options=None,
        is_extendable=False,
        syntax="proto2",
        extension_ranges=[],
        oneofs=[],
    )

    _FILEDESCRIPTORSET.fields_by_name["file"].message_type = _FILEDESCRIPTORPROTO
    _FILEDESCRIPTORPROTO.fields_by_name["message_type"].message_type = _DESCRIPTORPROTO
    _FILEDESCRIPTORPROTO.fields_by_name["enum_type"].message_type = _ENUMDESCRIPTORPROTO
    _FILEDESCRIPTORPROTO.fields_by_name[
        "service"
    ].message_type = _SERVICEDESCRIPTORPROTO
    _FILEDESCRIPTORPROTO.fields_by_name[
        "extension"
    ].message_type = _FIELDDESCRIPTORPROTO
    _FILEDESCRIPTORPROTO.fields_by_name["options"].message_type = _FILEOPTIONS
    _FILEDESCRIPTORPROTO.fields_by_name[
        "source_code_info"
    ].message_type = _SOURCECODEINFO
    _DESCRIPTORPROTO_EXTENSIONRANGE.fields_by_name[
        "options"
    ].message_type = _EXTENSIONRANGEOPTIONS
    _DESCRIPTORPROTO_EXTENSIONRANGE.containing_type = _DESCRIPTORPROTO
    _DESCRIPTORPROTO_RESERVEDRANGE.containing_type = _DESCRIPTORPROTO
    _DESCRIPTORPROTO.fields_by_name["field"].message_type = _FIELDDESCRIPTORPROTO
    _DESCRIPTORPROTO.fields_by_name["extension"].message_type = _FIELDDESCRIPTORPROTO
    _DESCRIPTORPROTO.fields_by_name["nested_type"].message_type = _DESCRIPTORPROTO
    _DESCRIPTORPROTO.fields_by_name["enum_type"].message_type = _ENUMDESCRIPTORPROTO
    _DESCRIPTORPROTO.fields_by_name[
        "extension_range"
    ].message_type = _DESCRIPTORPROTO_EXTENSIONRANGE
    _DESCRIPTORPROTO.fields_by_name["oneof_decl"].message_type = _ONEOFDESCRIPTORPROTO
    _DESCRIPTORPROTO.fields_by_name["options"].message_type = _MESSAGEOPTIONS
    _DESCRIPTORPROTO.fields_by_name[
        "reserved_range"
    ].message_type = _DESCRIPTORPROTO_RESERVEDRANGE
    _EXTENSIONRANGEOPTIONS.fields_by_name[
        "uninterpreted_option"
    ].message_type = _UNINTERPRETEDOPTION
    _FIELDDESCRIPTORPROTO.fields_by_name[
        "label"
    ].enum_type = _FIELDDESCRIPTORPROTO_LABEL
    _FIELDDESCRIPTORPROTO.fields_by_name["type"].enum_type = _FIELDDESCRIPTORPROTO_TYPE
    _FIELDDESCRIPTORPROTO.fields_by_name["options"].message_type = _FIELDOPTIONS
    _FIELDDESCRIPTORPROTO_TYPE.containing_type = _FIELDDESCRIPTORPROTO
    _FIELDDESCRIPTORPROTO_LABEL.containing_type = _FIELDDESCRIPTORPROTO
    _ONEOFDESCRIPTORPROTO.fields_by_name["options"].message_type = _ONEOFOPTIONS
    _ENUMDESCRIPTORPROTO_ENUMRESERVEDRANGE.containing_type = _ENUMDESCRIPTORPROTO
    _ENUMDESCRIPTORPROTO.fields_by_name[
        "value"
    ].message_type = _ENUMVALUEDESCRIPTORPROTO
    _ENUMDESCRIPTORPROTO.fields_by_name["options"].message_type = _ENUMOPTIONS
    _ENUMDESCRIPTORPROTO.fields_by_name[
        "reserved_range"
    ].message_type = _ENUMDESCRIPTORPROTO_ENUMRESERVEDRANGE
    _ENUMVALUEDESCRIPTORPROTO.fields_by_name["options"].message_type = _ENUMVALUEOPTIONS
    _SERVICEDESCRIPTORPROTO.fields_by_name[
        "method"
    ].message_type = _METHODDESCRIPTORPROTO
    _SERVICEDESCRIPTORPROTO.fields_by_name["options"].message_type = _SERVICEOPTIONS
    _METHODDESCRIPTORPROTO.fields_by_name["options"].message_type = _METHODOPTIONS
    _FILEOPTIONS.fields_by_name["optimize_for"].enum_type = _FILEOPTIONS_OPTIMIZEMODE
    _FILEOPTIONS.fields_by_name[
        "uninterpreted_option"
    ].message_type = _UNINTERPRETEDOPTION
    _FILEOPTIONS_OPTIMIZEMODE.containing_type = _FILEOPTIONS
    _MESSAGEOPTIONS.fields_by_name[
        "uninterpreted_option"
    ].message_type = _UNINTERPRETEDOPTION
    _FIELDOPTIONS.fields_by_name["ctype"].enum_type = _FIELDOPTIONS_CTYPE
    _FIELDOPTIONS.fields_by_name["jstype"].enum_type = _FIELDOPTIONS_JSTYPE
    _FIELDOPTIONS.fields_by_name["retention"].enum_type = _FIELDOPTIONS_OPTIONRETENTION
    _FIELDOPTIONS.fields_by_name["target"].enum_type = _FIELDOPTIONS_OPTIONTARGETTYPE
    _FIELDOPTIONS.fields_by_name[
        "uninterpreted_option"
    ].message_type = _UNINTERPRETEDOPTION
    _FIELDOPTIONS_CTYPE.containing_type = _FIELDOPTIONS
    _FIELDOPTIONS_JSTYPE.containing_type = _FIELDOPTIONS
    _FIELDOPTIONS_OPTIONRETENTION.containing_type = _FIELDOPTIONS
    _FIELDOPTIONS_OPTIONTARGETTYPE.containing_type = _FIELDOPTIONS
    _ONEOFOPTIONS.fields_by_name[
        "uninterpreted_option"
    ].message_type = _UNINTERPRETEDOPTION
    _ENUMOPTIONS.fields_by_name[
        "uninterpreted_option"
    ].message_type = _UNINTERPRETEDOPTION
    _ENUMVALUEOPTIONS.fields_by_name[
        "uninterpreted_option"
    ].message_type = _UNINTERPRETEDOPTION
    _SERVICEOPTIONS.fields_by_name[
        "uninterpreted_option"
    ].message_type = _UNINTERPRETEDOPTION
    _METHODOPTIONS.fields_by_name[
        "idempotency_level"
    ].enum_type = _METHODOPTIONS_IDEMPOTENCYLEVEL
    _METHODOPTIONS.fields_by_name[
        "uninterpreted_option"
    ].message_type = _UNINTERPRETEDOPTION
    _METHODOPTIONS_IDEMPOTENCYLEVEL.containing_type = _METHODOPTIONS
    _UNINTERPRETEDOPTION_NAMEPART.containing_type = _UNINTERPRETEDOPTION
    _UNINTERPRETEDOPTION.fields_by_name[
        "name"
    ].message_type = _UNINTERPRETEDOPTION_NAMEPART
    _SOURCECODEINFO_LOCATION.containing_type = _SOURCECODEINFO
    _SOURCECODEINFO.fields_by_name["location"].message_type = _SOURCECODEINFO_LOCATION
    _GENERATEDCODEINFO_ANNOTATION.fields_by_name[
        "semantic"
    ].enum_type = _GENERATEDCODEINFO_ANNOTATION_SEMANTIC
    _GENERATEDCODEINFO_ANNOTATION.containing_type = _GENERATEDCODEINFO
    _GENERATEDCODEINFO_ANNOTATION_SEMANTIC.containing_type = (
        _GENERATEDCODEINFO_ANNOTATION
    )
    _GENERATEDCODEINFO.fields_by_name[
        "annotation"
    ].message_type = _GENERATEDCODEINFO_ANNOTATION
    DESCRIPTOR.message_types_by_name["FileDescriptorSet"] = _FILEDESCRIPTORSET
    DESCRIPTOR.message_types_by_name["FileDescriptorProto"] = _FILEDESCRIPTORPROTO
    DESCRIPTOR.message_types_by_name["DescriptorProto"] = _DESCRIPTORPROTO
    DESCRIPTOR.message_types_by_name["ExtensionRangeOptions"] = _EXTENSIONRANGEOPTIONS
    DESCRIPTOR.message_types_by_name["FieldDescriptorProto"] = _FIELDDESCRIPTORPROTO
    DESCRIPTOR.message_types_by_name["OneofDescriptorProto"] = _ONEOFDESCRIPTORPROTO
    DESCRIPTOR.message_types_by_name["EnumDescriptorProto"] = _ENUMDESCRIPTORPROTO
    DESCRIPTOR.message_types_by_name[
        "EnumValueDescriptorProto"
    ] = _ENUMVALUEDESCRIPTORPROTO
    DESCRIPTOR.message_types_by_name["ServiceDescriptorProto"] = _SERVICEDESCRIPTORPROTO
    DESCRIPTOR.message_types_by_name["MethodDescriptorProto"] = _METHODDESCRIPTORPROTO
    DESCRIPTOR.message_types_by_name["FileOptions"] = _FILEOPTIONS
    DESCRIPTOR.message_types_by_name["MessageOptions"] = _MESSAGEOPTIONS
    DESCRIPTOR.message_types_by_name["FieldOptions"] = _FIELDOPTIONS
    DESCRIPTOR.message_types_by_name["OneofOptions"] = _ONEOFOPTIONS
    DESCRIPTOR.message_types_by_name["EnumOptions"] = _ENUMOPTIONS
    DESCRIPTOR.message_types_by_name["EnumValueOptions"] = _ENUMVALUEOPTIONS
    DESCRIPTOR.message_types_by_name["ServiceOptions"] = _SERVICEOPTIONS
    DESCRIPTOR.message_types_by_name["MethodOptions"] = _METHODOPTIONS
    DESCRIPTOR.message_types_by_name["UninterpretedOption"] = _UNINTERPRETEDOPTION
    DESCRIPTOR.message_types_by_name["SourceCodeInfo"] = _SOURCECODEINFO
    DESCRIPTOR.message_types_by_name["GeneratedCodeInfo"] = _GENERATEDCODEINFO
    _sym_db.RegisterFileDescriptor(DESCRIPTOR)

else:
    _builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "google.protobuf.descriptor_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_FILEDESCRIPTORSET"]._serialized_start = 53
    _globals["_FILEDESCRIPTORSET"]._serialized_end = 130
    _globals["_FILEDESCRIPTORPROTO"]._serialized_start = 133
    _globals["_FILEDESCRIPTORPROTO"]._serialized_end = 771
    _globals["_DESCRIPTORPROTO"]._serialized_start = 774
    _globals["_DESCRIPTORPROTO"]._serialized_end = 1599
    _globals["_DESCRIPTORPROTO_EXTENSIONRANGE"]._serialized_start = 1420
    _globals["_DESCRIPTORPROTO_EXTENSIONRANGE"]._serialized_end = 1542
    _globals["_DESCRIPTORPROTO_RESERVEDRANGE"]._serialized_start = 1544
    _globals["_DESCRIPTORPROTO_RESERVEDRANGE"]._serialized_end = 1599
    _globals["_EXTENSIONRANGEOPTIONS"]._serialized_start = 1601
    _globals["_EXTENSIONRANGEOPTIONS"]._serialized_end = 1725
    _globals["_FIELDDESCRIPTORPROTO"]._serialized_start = 1728
    _globals["_FIELDDESCRIPTORPROTO"]._serialized_end = 2561
    _globals["_FIELDDESCRIPTORPROTO_TYPE"]._serialized_start = 2182
    _globals["_FIELDDESCRIPTORPROTO_TYPE"]._serialized_end = 2492
    _globals["_FIELDDESCRIPTORPROTO_LABEL"]._serialized_start = 2494
    _globals["_FIELDDESCRIPTORPROTO_LABEL"]._serialized_end = 2561
    _globals["_ONEOFDESCRIPTORPROTO"]._serialized_start = 2563
    _globals["_ONEOFDESCRIPTORPROTO"]._serialized_end = 2662
    _globals["_ENUMDESCRIPTORPROTO"]._serialized_start = 2665
    _globals["_ENUMDESCRIPTORPROTO"]._serialized_end = 3020
    _globals["_ENUMDESCRIPTORPROTO_ENUMRESERVEDRANGE"]._serialized_start = 2961
    _globals["_ENUMDESCRIPTORPROTO_ENUMRESERVEDRANGE"]._serialized_end = 3020
    _globals["_ENUMVALUEDESCRIPTORPROTO"]._serialized_start = 3023
    _globals["_ENUMVALUEDESCRIPTORPROTO"]._serialized_end = 3154
    _globals["_SERVICEDESCRIPTORPROTO"]._serialized_start = 3157
    _globals["_SERVICEDESCRIPTORPROTO"]._serialized_end = 3324
    _globals["_METHODDESCRIPTORPROTO"]._serialized_start = 3327
    _globals["_METHODDESCRIPTORPROTO"]._serialized_end = 3592
    _globals["_FILEOPTIONS"]._serialized_start = 3595
    _globals["_FILEOPTIONS"]._serialized_end = 4764
    _globals["_FILEOPTIONS_OPTIMIZEMODE"]._serialized_start = 4689
    _globals["_FILEOPTIONS_OPTIMIZEMODE"]._serialized_end = 4747
    _globals["_MESSAGEOPTIONS"]._serialized_start = 4767
    _globals["_MESSAGEOPTIONS"]._serialized_end = 5210
    _globals["_FIELDOPTIONS"]._serialized_start = 5213
    _globals["_FIELDOPTIONS"]._serialized_end = 6292
    _globals["_FIELDOPTIONS_CTYPE"]._serialized_start = 5815
    _globals["_FIELDOPTIONS_CTYPE"]._serialized_end = 5862
    _globals["_FIELDOPTIONS_JSTYPE"]._serialized_start = 5864
    _globals["_FIELDOPTIONS_JSTYPE"]._serialized_end = 5917
    _globals["_FIELDOPTIONS_OPTIONRETENTION"]._serialized_start = 5919
    _globals["_FIELDOPTIONS_OPTIONRETENTION"]._serialized_end = 6004
    _globals["_FIELDOPTIONS_OPTIONTARGETTYPE"]._serialized_start = 6007
    _globals["_FIELDOPTIONS_OPTIONTARGETTYPE"]._serialized_end = 6275
    _globals["_ONEOFOPTIONS"]._serialized_start = 6294
    _globals["_ONEOFOPTIONS"]._serialized_end = 6409
    _globals["_ENUMOPTIONS"]._serialized_start = 6412
    _globals["_ENUMOPTIONS"]._serialized_end = 6692
    _globals["_ENUMVALUEOPTIONS"]._serialized_start = 6695
    _globals["_ENUMVALUEOPTIONS"]._serialized_end = 6853
    _globals["_SERVICEOPTIONS"]._serialized_start = 6856
    _globals["_SERVICEOPTIONS"]._serialized_end = 7012
    _globals["_METHODOPTIONS"]._serialized_start = 7015
    _globals["_METHODOPTIONS"]._serialized_end = 7367
    _globals["_METHODOPTIONS_IDEMPOTENCYLEVEL"]._serialized_start = 7276
    _globals["_METHODOPTIONS_IDEMPOTENCYLEVEL"]._serialized_end = 7356
    _globals["_UNINTERPRETEDOPTION"]._serialized_start = 7370
    _globals["_UNINTERPRETEDOPTION"]._serialized_end = 7780
    _globals["_UNINTERPRETEDOPTION_NAMEPART"]._serialized_start = 7706
    _globals["_UNINTERPRETEDOPTION_NAMEPART"]._serialized_end = 7780
    _globals["_SOURCECODEINFO"]._serialized_start = 7783
    _globals["_SOURCECODEINFO"]._serialized_end = 8078
    _globals["_SOURCECODEINFO_LOCATION"]._serialized_start = 7872
    _globals["_SOURCECODEINFO_LOCATION"]._serialized_end = 8078
    _globals["_GENERATEDCODEINFO"]._serialized_start = 8081
    _globals["_GENERATEDCODEINFO"]._serialized_end = 8417
    _globals["_GENERATEDCODEINFO_ANNOTATION"]._serialized_start = 8182
    _globals["_GENERATEDCODEINFO_ANNOTATION"]._serialized_end = 8417
    _globals["_GENERATEDCODEINFO_ANNOTATION_SEMANTIC"]._serialized_start = 8377
    _globals["_GENERATEDCODEINFO_ANNOTATION_SEMANTIC"]._serialized_end = 8417
# @@protoc_insertion_point(module_scope)
